package Monitoring::GLPlugin::SNMP::MibsAndOids::AIRESPACEWIRELESSMIB;

$Monitoring::GLPlugin::SNMP::MibsAndOids::origin->{'AIRESPACE-WIRELESS-MIB'} = {
  url => '',
  name => 'AIRESPACE-WIRELESS-MIB',
};

$Monitoring::GLPlugin::SNMP::MibsAndOids::mib_ids->{'AIRESPACE-WIRELESS-MIB'} =
  '1.3.6.1.4.1.14179.2';

$Monitoring::GLPlugin::SNMP::MibsAndOids::mibs_and_oids->{'AIRESPACE-WIRELESS-MIB'} = {
  'bsnWireless' => '1.3.6.1.4.1.14179.2',
  'bsnEss' => '1.3.6.1.4.1.14179.2.1',
  'bsnDot11EssTable' => '1.3.6.1.4.1.14179.2.1.1',
  'bsnDot11EssEntry' => '1.3.6.1.4.1.14179.2.1.1.1',
  'bsnDot11EssIndex' => '1.3.6.1.4.1.14179.2.1.1.1.1',
  'bsnDot11EssSsid' => '1.3.6.1.4.1.14179.2.1.1.1.2',
  'bsnDot11EssSessionTimeout' => '1.3.6.1.4.1.14179.2.1.1.1.4',
  'bsnDot11EssMacFiltering' => '1.3.6.1.4.1.14179.2.1.1.1.5',
  'bsnDot11EssAdminStatus' => '1.3.6.1.4.1.14179.2.1.1.1.6',
  'bsnDot11EssSecurityAuthType' => '1.3.6.1.4.1.14179.2.1.1.1.7',
  'bsnDot11EssStaticWEPSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.8',
  'bsnDot11EssStaticWEPEncryptionType' => '1.3.6.1.4.1.14179.2.1.1.1.9',
  'bsnDot11EssStaticWEPDefaultKey' => '1.3.6.1.4.1.14179.2.1.1.1.10',
  'bsnDot11EssStaticWEPKeyIndex' => '1.3.6.1.4.1.14179.2.1.1.1.11',
  'bsnDot11EssStaticWEPKeyFormat' => '1.3.6.1.4.1.14179.2.1.1.1.12',
  'bsnDot11Ess8021xSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.13',
  'bsnDot11Ess8021xEncryptionType' => '1.3.6.1.4.1.14179.2.1.1.1.14',
  'bsnDot11EssWPASecurity' => '1.3.6.1.4.1.14179.2.1.1.1.16',
  'bsnDot11EssWPAEncryptionType' => '1.3.6.1.4.1.14179.2.1.1.1.17',
  'bsnDot11EssIpsecSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.18',
  'bsnDot11EssVpnEncrTransform' => '1.3.6.1.4.1.14179.2.1.1.1.19',
  'bsnDot11EssVpnAuthTransform' => '1.3.6.1.4.1.14179.2.1.1.1.20',
  'bsnDot11EssVpnIkeAuthMode' => '1.3.6.1.4.1.14179.2.1.1.1.21',
  'bsnDot11EssVpnSharedKey' => '1.3.6.1.4.1.14179.2.1.1.1.22',
  'bsnDot11EssVpnSharedKeySize' => '1.3.6.1.4.1.14179.2.1.1.1.23',
  'bsnDot11EssVpnIkePhase1Mode' => '1.3.6.1.4.1.14179.2.1.1.1.24',
  'bsnDot11EssVpnIkeLifetime' => '1.3.6.1.4.1.14179.2.1.1.1.25',
  'bsnDot11EssVpnIkeDHGroup' => '1.3.6.1.4.1.14179.2.1.1.1.26',
  'bsnDot11EssIpsecPassthruSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.27',
  'bsnDot11EssVpnPassthruGateway' => '1.3.6.1.4.1.14179.2.1.1.1.28',
  'bsnDot11EssWebSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.29',
  'bsnDot11EssRadioPolicy' => '1.3.6.1.4.1.14179.2.1.1.1.30',
  'bsnDot11EssQualityOfService' => '1.3.6.1.4.1.14179.2.1.1.1.31',
  'bsnDot11EssDhcpRequired' => '1.3.6.1.4.1.14179.2.1.1.1.32',
  'bsnDot11EssDhcpServerIpAddress' => '1.3.6.1.4.1.14179.2.1.1.1.33',
  'bsnDot11EssVpnContivityMode' => '1.3.6.1.4.1.14179.2.1.1.1.34',
  'bsnDot11EssVpnQotdServerAddress' => '1.3.6.1.4.1.14179.2.1.1.1.35',
  'bsnDot11EssBlacklistTimeout' => '1.3.6.1.4.1.14179.2.1.1.1.37',
  'bsnDot11EssNumberOfMobileStations' => '1.3.6.1.4.1.14179.2.1.1.1.38',
  'bsnDot11EssWebPassthru' => '1.3.6.1.4.1.14179.2.1.1.1.39',
  'bsnDot11EssCraniteSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.40',
  'bsnDot11EssBlacklistingCapability' => '1.3.6.1.4.1.14179.2.1.1.1.41',
  'bsnDot11EssInterfaceName' => '1.3.6.1.4.1.14179.2.1.1.1.42',
  'bsnDot11EssAclName' => '1.3.6.1.4.1.14179.2.1.1.1.43',
  'bsnDot11EssAAAOverride' => '1.3.6.1.4.1.14179.2.1.1.1.44',
  'bsnDot11EssWPAAuthKeyMgmtMode' => '1.3.6.1.4.1.14179.2.1.1.1.45',
  'bsnDot11EssWPAAuthPresharedKey' => '1.3.6.1.4.1.14179.2.1.1.1.46',
  'bsnDot11EssFortressSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.47',
  'bsnDot11EssWepAllowSharedKeyAuth' => '1.3.6.1.4.1.14179.2.1.1.1.48',
  'bsnDot11EssL2tpSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.49',
  'bsnDot11EssWPAAuthPresharedKeyHex' => '1.3.6.1.4.1.14179.2.1.1.1.50',
  'bsnDot11EssBroadcastSsid' => '1.3.6.1.4.1.14179.2.1.1.1.51',
  'bsnDot11EssExternalPolicyValidation' => '1.3.6.1.4.1.14179.2.1.1.1.52',
  'bsnDot11EssRSNSecurity' => '1.3.6.1.4.1.14179.2.1.1.1.53',
  'bsnDot11EssRSNWPACompatibilityMode' => '1.3.6.1.4.1.14179.2.1.1.1.54',
  'bsnDot11EssRSNAllowTKIPClients' => '1.3.6.1.4.1.14179.2.1.1.1.55',
  'bsnDot11EssRSNAuthKeyMgmtMode' => '1.3.6.1.4.1.14179.2.1.1.1.56',
  'bsnDot11EssRSNAuthPresharedKey' => '1.3.6.1.4.1.14179.2.1.1.1.57',
  'bsnDot11EssRSNAuthPresharedKeyHex' => '1.3.6.1.4.1.14179.2.1.1.1.58',
  'bsnDot11EssIPv6Bridging' => '1.3.6.1.4.1.14179.2.1.1.1.59',
  'bsnDot11EssRowStatus' => '1.3.6.1.4.1.14179.2.1.1.1.60',
  'bsnDot11EssWmePolicySetting' => '1.3.6.1.4.1.14179.2.1.1.1.61',
  'bsnDot11Ess80211ePolicySetting' => '1.3.6.1.4.1.14179.2.1.1.1.62',
  'bsnDot11EssWebPassthroughEmail' => '1.3.6.1.4.1.14179.2.1.1.1.63',
  'bsnDot11Ess7920PhoneSupport' => '1.3.6.1.4.1.14179.2.1.1.1.64',
  'bsnDot11EssRadiusAuthPrimaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.95',
  'bsnDot11EssRadiusAuthSecondaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.96',
  'bsnDot11EssRadiusAuthTertiaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.97',
  'bsnDot11EssRadiusAcctPrimaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.98',
  'bsnDot11EssRadiusAcctSecondaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.99',
  'bsnDot11EssRadiusAcctTertiaryServer' => '1.3.6.1.4.1.14179.2.1.1.1.100',
  'bsnMobileStationTable' => '1.3.6.1.4.1.14179.2.1.4',
  'bsnMobileStationEntry' => '1.3.6.1.4.1.14179.2.1.4.1',
  'bsnMobileStationMacAddress' => '1.3.6.1.4.1.14179.2.1.4.1.1',
  'bsnMobileStationIpAddress' => '1.3.6.1.4.1.14179.2.1.4.1.2',
  'bsnMobileStationUserName' => '1.3.6.1.4.1.14179.2.1.4.1.3',
  'bsnMobileStationAPMacAddr' => '1.3.6.1.4.1.14179.2.1.4.1.4',
  'bsnMobileStationAPIfSlotId' => '1.3.6.1.4.1.14179.2.1.4.1.5',
  'bsnMobileStationEssIndex' => '1.3.6.1.4.1.14179.2.1.4.1.6',
  'bsnMobileStationSsid' => '1.3.6.1.4.1.14179.2.1.4.1.7',
  'bsnMobileStationAID' => '1.3.6.1.4.1.14179.2.1.4.1.8',
  'bsnMobileStationStatus' => '1.3.6.1.4.1.14179.2.1.4.1.9',
  'bsnMobileStationReasonCode' => '1.3.6.1.4.1.14179.2.1.4.1.10',
  'bsnMobileStationMobilityStatus' => '1.3.6.1.4.1.14179.2.1.4.1.11',
  'bsnMobileStationAnchorAddress' => '1.3.6.1.4.1.14179.2.1.4.1.12',
  'bsnMobileStationCFPollable' => '1.3.6.1.4.1.14179.2.1.4.1.13',
  'bsnMobileStationCFPollRequest' => '1.3.6.1.4.1.14179.2.1.4.1.14',
  'bsnMobileStationChannelAgilityEnabled' => '1.3.6.1.4.1.14179.2.1.4.1.15',
  'bsnMobileStationPBCCOptionImplemented' => '1.3.6.1.4.1.14179.2.1.4.1.16',
  'bsnMobileStationShortPreambleOptionImplemented' => '1.3.6.1.4.1.14179.2.1.4.1.17',
  'bsnMobileStationSessionTimeout' => '1.3.6.1.4.1.14179.2.1.4.1.18',
  'bsnMobileStationAuthenticationAlgorithm' => '1.3.6.1.4.1.14179.2.1.4.1.19',
  'bsnMobileStationWepState' => '1.3.6.1.4.1.14179.2.1.4.1.20',
  'bsnMobileStationPortNumber' => '1.3.6.1.4.1.14179.2.1.4.1.21',
  'bsnMobileStationDeleteAction' => '1.3.6.1.4.1.14179.2.1.4.1.22',
  'bsnMobileStationPolicyManagerState' => '1.3.6.1.4.1.14179.2.1.4.1.23',
  'bsnMobileStationSecurityPolicyStatus' => '1.3.6.1.4.1.14179.2.1.4.1.24',
  'bsnMobileStationProtocol' => '1.3.6.1.4.1.14179.2.1.4.1.25',
  'bsnMobileStationMirrorMode' => '1.3.6.1.4.1.14179.2.1.4.1.26',
  'bsnMobileStationInterface' => '1.3.6.1.4.1.14179.2.1.4.1.27',
  'bsnMobileStationApMode' => '1.3.6.1.4.1.14179.2.1.4.1.28',
  'bsnMobileStationVlanId' => '1.3.6.1.4.1.14179.2.1.4.1.29',
  'bsnMobileStationPolicyType' => '1.3.6.1.4.1.14179.2.1.4.1.30',
  'bsnMobileStationEncryptionCypher' => '1.3.6.1.4.1.14179.2.1.4.1.31',
  'bsnMobileStationEapType' => '1.3.6.1.4.1.14179.2.1.4.1.32',
  'bsnMobileStationCcxVersion' => '1.3.6.1.4.1.14179.2.1.4.1.33',
  'bsnMobileStationE2eVersion' => '1.3.6.1.4.1.14179.2.1.4.1.34',
  'bsnMobileStationStatusCode' => '1.3.6.1.4.1.14179.2.1.4.1.42',
  'bsnMobileStationPerRadioPerVapTable' => '1.3.6.1.4.1.14179.2.1.5',
  'bsnMobileStationPerRadioPerVapEntry' => '1.3.6.1.4.1.14179.2.1.5.1',
  'bsnMobileStationPerRadioPerVapIndex' => '1.3.6.1.4.1.14179.2.1.5.1.1',
  'bsnMobileStationMacAddr' => '1.3.6.1.4.1.14179.2.1.5.1.20',
  'bsnMobileStationStatsTable' => '1.3.6.1.4.1.14179.2.1.6',
  'bsnMobileStationStatsEntry' => '1.3.6.1.4.1.14179.2.1.6.1',
  'bsnMobileStationRSSI' => '1.3.6.1.4.1.14179.2.1.6.1.1',
  'bsnMobileStationBytesReceived' => '1.3.6.1.4.1.14179.2.1.6.1.2',
  'bsnMobileStationBytesSent' => '1.3.6.1.4.1.14179.2.1.6.1.3',
  'bsnMobileStationPolicyErrors' => '1.3.6.1.4.1.14179.2.1.6.1.4',
  'bsnMobileStationPacketsReceived' => '1.3.6.1.4.1.14179.2.1.6.1.5',
  'bsnMobileStationPacketsSent' => '1.3.6.1.4.1.14179.2.1.6.1.6',
  'bsnMobileStationSnr' => '1.3.6.1.4.1.14179.2.1.6.1.26',
  'bsnRogueAPTable' => '1.3.6.1.4.1.14179.2.1.7',
  'bsnRogueAPEntry' => '1.3.6.1.4.1.14179.2.1.7.1',
  'bsnRogueAPDot11MacAddress' => '1.3.6.1.4.1.14179.2.1.7.1.1',
  'bsnRogueAPTotalDetectingAPs' => '1.3.6.1.4.1.14179.2.1.7.1.2',
  'bsnRogueAPFirstReported' => '1.3.6.1.4.1.14179.2.1.7.1.3',
  'bsnRogueAPLastReported' => '1.3.6.1.4.1.14179.2.1.7.1.4',
  'bsnRogueAPContainmentLevel' => '1.3.6.1.4.1.14179.2.1.7.1.5',
  'bsnRogueAPType' => '1.3.6.1.4.1.14179.2.1.7.1.6',
  'bsnRogueAPOnNetwork' => '1.3.6.1.4.1.14179.2.1.7.1.7',
  'bsnRogueAPTotalClients' => '1.3.6.1.4.1.14179.2.1.7.1.8',
  'bsnRogueAPRowStatus' => '1.3.6.1.4.1.14179.2.1.7.1.9',
  'bsnRogueAPMaxDetectedRSSI' => '1.3.6.1.4.1.14179.2.1.7.1.10',
  'bsnRogueAPSSID' => '1.3.6.1.4.1.14179.2.1.7.1.11',
  'bsnRogueAPDetectingAPRadioType' => '1.3.6.1.4.1.14179.2.1.7.1.12',
  'bsnRogueAPDetectingAPMacAddress' => '1.3.6.1.4.1.14179.2.1.7.1.13',
  'bsnRogueAPMaxRssiRadioType' => '1.3.6.1.4.1.14179.2.1.7.1.14',
  'bsnRogueAPState' => '1.3.6.1.4.1.14179.2.1.7.1.24',
  'bsnRogueAPClassType' => '1.3.6.1.4.1.14179.2.1.7.1.25',
  'bsnRogueAPChannel' => '1.3.6.1.4.1.14179.2.1.7.1.26',
  'bsnRogueAPDetectingAPName' => '1.3.6.1.4.1.14179.2.1.7.1.27',
  'bsnRogueAPAirespaceAPTable' => '1.3.6.1.4.1.14179.2.1.8',
  'bsnRogueAPAirespaceAPEntry' => '1.3.6.1.4.1.14179.2.1.8.1',
  'bsnRogueAPAirespaceAPMacAddress' => '1.3.6.1.4.1.14179.2.1.8.1.1',
  'bsnRogueAPAirespaceAPSlotId' => '1.3.6.1.4.1.14179.2.1.8.1.2',
  'bsnRogueAPRadioType' => '1.3.6.1.4.1.14179.2.1.8.1.3',
  'bsnRogueAPAirespaceAPName' => '1.3.6.1.4.1.14179.2.1.8.1.4',
  'bsnRogueAPChannelNumber' => '1.3.6.1.4.1.14179.2.1.8.1.5',
  'bsnRogueAPSsid' => '1.3.6.1.4.1.14179.2.1.8.1.6',
  'bsnRogueAPAirespaceAPRSSI' => '1.3.6.1.4.1.14179.2.1.8.1.7',
  'bsnRogueAPContainmentMode' => '1.3.6.1.4.1.14179.2.1.8.1.8',
  'bsnRogueAPContainmentChannelCount' => '1.3.6.1.4.1.14179.2.1.8.1.9',
  'bsnRogueAPContainmentChannels' => '1.3.6.1.4.1.14179.2.1.8.1.10',
  'bsnRogueAPAirespaceAPLastHeard' => '1.3.6.1.4.1.14179.2.1.8.1.11',
  'bsnRogueAPAirespaceAPWepMode' => '1.3.6.1.4.1.14179.2.1.8.1.12',
  'bsnRogueAPAirespaceAPPreamble' => '1.3.6.1.4.1.14179.2.1.8.1.13',
  'bsnRogueAPAirespaceAPWpaMode' => '1.3.6.1.4.1.14179.2.1.8.1.14',
  'bsnRogueAPAirespaceAPSNR' => '1.3.6.1.4.1.14179.2.1.8.1.27',
  'bsnRogueAPChannelWidth' => '1.3.6.1.4.1.14179.2.1.8.1.28',
  'bsnThirdPartyAPTable' => '1.3.6.1.4.1.14179.2.1.9',
  'bsnThirdPartyAPEntry' => '1.3.6.1.4.1.14179.2.1.9.1',
  'bsnThirdPartyAPMacAddress' => '1.3.6.1.4.1.14179.2.1.9.1.1',
  'bsnThirdPartyAPInterface' => '1.3.6.1.4.1.14179.2.1.9.1.2',
  'bsnThirdPartyAPIpAddress' => '1.3.6.1.4.1.14179.2.1.9.1.3',
  'bsnThirdPartyAP802Dot1XRequired' => '1.3.6.1.4.1.14179.2.1.9.1.4',
  'bsnThirdPartyAPMirrorMode' => '1.3.6.1.4.1.14179.2.1.9.1.5',
  'bsnThirdPartyAPRowStatus' => '1.3.6.1.4.1.14179.2.1.9.1.24',
  'bsnMobileStationByIpTable' => '1.3.6.1.4.1.14179.2.1.10',
  'bsnMobileStationByIpEntry' => '1.3.6.1.4.1.14179.2.1.10.1',
  'bsnMobileStationByIpAddress' => '1.3.6.1.4.1.14179.2.1.10.1.1',
  'bsnMobileStationByIpMacAddress' => '1.3.6.1.4.1.14179.2.1.10.1.2',
  'bsnMobileStationRssiDataTable' => '1.3.6.1.4.1.14179.2.1.11',
  'bsnMobileStationRssiDataEntry' => '1.3.6.1.4.1.14179.2.1.11.1',
  'bsnMobileStationRssiDataApMacAddress' => '1.3.6.1.4.1.14179.2.1.11.1.1',
  'bsnMobileStationRssiDataApIfSlotId' => '1.3.6.1.4.1.14179.2.1.11.1.2',
  'bsnMobileStationRssiDataApIfType' => '1.3.6.1.4.1.14179.2.1.11.1.3',
  'bsnMobileStationRssiDataApName' => '1.3.6.1.4.1.14179.2.1.11.1.4',
  'bsnMobileStationRssiData' => '1.3.6.1.4.1.14179.2.1.11.1.5',
  'bsnAPIfPhyAntennaIndex' => '1.3.6.1.4.1.14179.2.1.11.1.6',
  'bsnMobileStationRssiDataLastHeard' => '1.3.6.1.4.1.14179.2.1.11.1.25',
  'bsnWatchListClientTable' => '1.3.6.1.4.1.14179.2.1.12',
  'bsnWatchListClientEntry' => '1.3.6.1.4.1.14179.2.1.12.1',
  'bsnWatchListClientKey' => '1.3.6.1.4.1.14179.2.1.12.1.1',
  'bsnWatchListClientType' => '1.3.6.1.4.1.14179.2.1.12.1.2',
  'bsnWatchListClientRowStatus' => '1.3.6.1.4.1.14179.2.1.12.1.20',
  'bsnMobileStationByUsernameTable' => '1.3.6.1.4.1.14179.2.1.13',
  'bsnMobileStationByUsernameEntry' => '1.3.6.1.4.1.14179.2.1.13.1',
  'bsnMobileStationByUserName' => '1.3.6.1.4.1.14179.2.1.13.1.1',
  'bsnMobileStationByUserMacAddress' => '1.3.6.1.4.1.14179.2.1.13.1.2',
  'bsnRogueClientTable' => '1.3.6.1.4.1.14179.2.1.14',
  'bsnRogueClientEntry' => '1.3.6.1.4.1.14179.2.1.14.1',
  'bsnRogueClientDot11MacAddress' => '1.3.6.1.4.1.14179.2.1.14.1.1',
  'bsnRogueClientTotalDetectingAPs' => '1.3.6.1.4.1.14179.2.1.14.1.2',
  'bsnRogueClientFirstReported' => '1.3.6.1.4.1.14179.2.1.14.1.3',
  'bsnRogueClientLastReported' => '1.3.6.1.4.1.14179.2.1.14.1.4',
  'bsnRogueClientBSSID' => '1.3.6.1.4.1.14179.2.1.14.1.5',
  'bsnRogueClientContainmentLevel' => '1.3.6.1.4.1.14179.2.1.14.1.6',
  'bsnRogueClientLastHeard' => '1.3.6.1.4.1.14179.2.1.14.1.7',
  'bsnRogueClientState' => '1.3.6.1.4.1.14179.2.1.14.1.24',
  'bsnRogueClientAirespaceAPTable' => '1.3.6.1.4.1.14179.2.1.15',
  'bsnRogueClientAirespaceAPEntry' => '1.3.6.1.4.1.14179.2.1.15.1',
  'bsnRogueClientAirespaceAPMacAddress' => '1.3.6.1.4.1.14179.2.1.15.1.1',
  'bsnRogueClientAirespaceAPSlotId' => '1.3.6.1.4.1.14179.2.1.15.1.2',
  'bsnRogueClientRadioType' => '1.3.6.1.4.1.14179.2.1.15.1.3',
  'bsnRogueClientAirespaceAPName' => '1.3.6.1.4.1.14179.2.1.15.1.4',
  'bsnRogueClientChannelNumber' => '1.3.6.1.4.1.14179.2.1.15.1.5',
  'bsnRogueClientAirespaceAPRSSI' => '1.3.6.1.4.1.14179.2.1.15.1.7',
  'bsnRogueClientAirespaceAPLastHeard' => '1.3.6.1.4.1.14179.2.1.15.1.11',
  'bsnRogueClientAirespaceAPSNR' => '1.3.6.1.4.1.14179.2.1.15.1.27',
  'bsnRogueClientPerRogueAPTable' => '1.3.6.1.4.1.14179.2.1.16',
  'bsnRogueClientPerRogueAPEntry' => '1.3.6.1.4.1.14179.2.1.16.1',
  'bsnRogueAPDot11MacAddr' => '1.3.6.1.4.1.14179.2.1.16.1.1',
  'bsnRogueClientDot11MacAddr' => '1.3.6.1.4.1.14179.2.1.16.1.20',
  'bsnDot11QosProfileTable' => '1.3.6.1.4.1.14179.2.1.17',
  'bsnDot11QosProfileEntry' => '1.3.6.1.4.1.14179.2.1.17.1',
  'bsnDot11QosProfileName' => '1.3.6.1.4.1.14179.2.1.17.1.1',
  'bsnDot11QosProfileDesc' => '1.3.6.1.4.1.14179.2.1.17.1.2',
  'bsnDot11QosAverageDataRate' => '1.3.6.1.4.1.14179.2.1.17.1.3',
  'bsnDot11QosBurstDataRate' => '1.3.6.1.4.1.14179.2.1.17.1.4',
  'bsnDot11QosAvgRealTimeDataRate' => '1.3.6.1.4.1.14179.2.1.17.1.5',
  'bsnDot11QosBurstRealTimeDataRate' => '1.3.6.1.4.1.14179.2.1.17.1.6',
  'bsnDot11QosMaxRFUsagePerAP' => '1.3.6.1.4.1.14179.2.1.17.1.7',
  'bsnDot11QosProfileQueueDepth' => '1.3.6.1.4.1.14179.2.1.17.1.8',
  'bsnDot11WiredQosProtocol' => '1.3.6.1.4.1.14179.2.1.17.1.9',
  'bsnDot11802Dot1PTag' => '1.3.6.1.4.1.14179.2.1.17.1.10',
  'bsnDot11ResetProfileToDefault' => '1.3.6.1.4.1.14179.2.1.17.1.40',
  'bsnTagTable' => '1.3.6.1.4.1.14179.2.1.18',
  'bsnTagEntry' => '1.3.6.1.4.1.14179.2.1.18.1',
  'bsnTagDot11MacAddress' => '1.3.6.1.4.1.14179.2.1.18.1.1',
  'bsnTagType' => '1.3.6.1.4.1.14179.2.1.18.1.2',
  'bsnTagTimeInterval' => '1.3.6.1.4.1.14179.2.1.18.1.3',
  'bsnTagBatteryStatus' => '1.3.6.1.4.1.14179.2.1.18.1.4',
  'bsnTagLastReported' => '1.3.6.1.4.1.14179.2.1.18.1.23',
  'bsnTagRssiDataTable' => '1.3.6.1.4.1.14179.2.1.19',
  'bsnTagRssiDataEntry' => '1.3.6.1.4.1.14179.2.1.19.1',
  'bsnTagRssiDataApMacAddress' => '1.3.6.1.4.1.14179.2.1.19.1.1',
  'bsnTagRssiDataApIfSlotId' => '1.3.6.1.4.1.14179.2.1.19.1.2',
  'bsnTagRssiDataApIfType' => '1.3.6.1.4.1.14179.2.1.19.1.3',
  'bsnTagRssiDataApName' => '1.3.6.1.4.1.14179.2.1.19.1.4',
  'bsnTagRssiDataLastHeard' => '1.3.6.1.4.1.14179.2.1.19.1.5',
  'bsnTagRssiData' => '1.3.6.1.4.1.14179.2.1.19.1.6',
  'bsnTagRssiDataSnr' => '1.3.6.1.4.1.14179.2.1.19.1.26',
  'bsnTagStatsTable' => '1.3.6.1.4.1.14179.2.1.20',
  'bsnTagStatsEntry' => '1.3.6.1.4.1.14179.2.1.20.1',
  'bsnTagBytesReceived' => '1.3.6.1.4.1.14179.2.1.20.1.1',
  'bsnTagPacketsReceived' => '1.3.6.1.4.1.14179.2.1.20.1.20',
  'bsnMobileStationExtStatsTable' => '1.3.6.1.4.1.14179.2.1.21',
  'bsnMobileStationExtStatsEntry' => '1.3.6.1.4.1.14179.2.1.21.1',
  'bsnMobileStationSampleTime' => '1.3.6.1.4.1.14179.2.1.21.1.1',
  'bsnMobileStationTxExcessiveRetries' => '1.3.6.1.4.1.14179.2.1.21.1.2',
  'bsnMobileStationTxRetries' => '1.3.6.1.4.1.14179.2.1.21.1.3',
  'bsnMobileStationTxFiltered' => '1.3.6.1.4.1.14179.2.1.21.1.20',
  'bsnAP' => '1.3.6.1.4.1.14179.2.2',
  'bsnAPTable' => '1.3.6.1.4.1.14179.2.2.1',
  'bsnAPEntry' => '1.3.6.1.4.1.14179.2.2.1.1',
  'bsnAPDot3MacAddress' => '1.3.6.1.4.1.14179.2.2.1.1.1',
  'bsnAPNumOfSlots' => '1.3.6.1.4.1.14179.2.2.1.1.2',
  'bsnAPName' => '1.3.6.1.4.1.14179.2.2.1.1.3',
  'bsnAPLocation' => '1.3.6.1.4.1.14179.2.2.1.1.4',
  'bsnAPMonitorOnlyMode' => '1.3.6.1.4.1.14179.2.2.1.1.5',
  'bsnAPOperationStatus' => '1.3.6.1.4.1.14179.2.2.1.1.6',
  'bsnAPOperationStatusDefinition' => {
    '1' => 'associated',
    '2' => 'disassociating',
    '3' => 'downloading',
  },
  'bsnAPSoftwareVersion' => '1.3.6.1.4.1.14179.2.2.1.1.8',
  'bsnAPBootVersion' => '1.3.6.1.4.1.14179.2.2.1.1.9',
  'bsnAPPrimaryMwarName' => '1.3.6.1.4.1.14179.2.2.1.1.10',
  'bsnAPReset' => '1.3.6.1.4.1.14179.2.2.1.1.11',
  'bsnAPStatsTimer' => '1.3.6.1.4.1.14179.2.2.1.1.12',
  'bsnAPPortNumber' => '1.3.6.1.4.1.14179.2.2.1.1.13',
  'bsnAPModel' => '1.3.6.1.4.1.14179.2.2.1.1.16',
  'bsnAPSerialNumber' => '1.3.6.1.4.1.14179.2.2.1.1.17',
  'bsnAPClearConfig' => '1.3.6.1.4.1.14179.2.2.1.1.18',
  'bsnApIpAddress' => '1.3.6.1.4.1.14179.2.2.1.1.19',
  'bsnAPMirrorMode' => '1.3.6.1.4.1.14179.2.2.1.1.20',
  'bsnAPRemoteModeSupport' => '1.3.6.1.4.1.14179.2.2.1.1.21',
  'bsnAPType' => '1.3.6.1.4.1.14179.2.2.1.1.22',
  'bsnAPTypeDefinition' => {
    '1' => 'ap1000',
    '2' => 'ap1030',
    '3' => 'mimo',
    '4' => 'unknown',
    '5' => 'ap1100',
    '6' => 'ap1130',
    '7' => 'ap1240',
    '8' => 'ap1200',
    '9' => 'ap1310',
    '10' => 'ap1500',
    '11' => 'ap1250',
    '12' => 'ap1505',
    '13' => 'ap3201',
    '14' => 'ap1520',
    '15' => 'ap800',
    '16' => 'ap1140',
    '17' => 'ap800agn',
    '18' => 'ap3500i',
    '19' => 'ap3500e',
    '20' => 'ap1260',
  },
  'bsnAPSecondaryMwarName' => '1.3.6.1.4.1.14179.2.2.1.1.23',
  'bsnAPTertiaryMwarName' => '1.3.6.1.4.1.14179.2.2.1.1.24',
  'bsnAPIsStaticIP' => '1.3.6.1.4.1.14179.2.2.1.1.25',
  'bsnAPNetmask' => '1.3.6.1.4.1.14179.2.2.1.1.26',
  'bsnAPGateway' => '1.3.6.1.4.1.14179.2.2.1.1.27',
  'bsnAPStaticIPAddress' => '1.3.6.1.4.1.14179.2.2.1.1.28',
  'bsnAPBridgingSupport' => '1.3.6.1.4.1.14179.2.2.1.1.29',
  'bsnAPGroupVlanName' => '1.3.6.1.4.1.14179.2.2.1.1.30',
  'bsnAPIOSVersion' => '1.3.6.1.4.1.14179.2.2.1.1.31',
  'bsnAPCertificateType' => '1.3.6.1.4.1.14179.2.2.1.1.32',
  'bsnAPEthernetMacAddress' => '1.3.6.1.4.1.14179.2.2.1.1.33',
  'bsnAPAdminStatus' => '1.3.6.1.4.1.14179.2.2.1.1.37',
  'bsnAPAdminStatusDefinition' => {
    '1' => 'enable',
    '2' => 'disable',
  },
  'bsnAPIfTable' => '1.3.6.1.4.1.14179.2.2.2',
  'bsnAPIfEntry' => '1.3.6.1.4.1.14179.2.2.2.1',
  'bsnAPIfSlotId' => '1.3.6.1.4.1.14179.2.2.2.1.1',
  'bsnAPIfType' => '1.3.6.1.4.1.14179.2.2.2.1.2',
  'bsnAPIfPhyChannelAssignment' => '1.3.6.1.4.1.14179.2.2.2.1.3',
  'bsnAPIfPhyChannelNumber' => '1.3.6.1.4.1.14179.2.2.2.1.4',
  'bsnAPIfPhyTxPowerControl' => '1.3.6.1.4.1.14179.2.2.2.1.5',
  'bsnAPIfPhyTxPowerLevel' => '1.3.6.1.4.1.14179.2.2.2.1.6',
  'bsnAPIfPhyAntennaMode' => '1.3.6.1.4.1.14179.2.2.2.1.7',
  'bsnAPIfPhyAntennaType' => '1.3.6.1.4.1.14179.2.2.2.1.8',
  'bsnAPIfPhyAntennaDiversity' => '1.3.6.1.4.1.14179.2.2.2.1.9',
  'bsnAPIfCellSiteConfigId' => '1.3.6.1.4.1.14179.2.2.2.1.10',
  'bsnAPIfNumberOfVaps' => '1.3.6.1.4.1.14179.2.2.2.1.11',
  'bsnAPIfOperStatus' => '1.3.6.1.4.1.14179.2.2.2.1.12',
  'bsnAPIfPortNumber' => '1.3.6.1.4.1.14179.2.2.2.1.13',
  'bsnAPIfPhyAntennaOptions' => '1.3.6.1.4.1.14179.2.2.2.1.14',
  'bsnApIfNoOfUsers' => '1.3.6.1.4.1.14179.2.2.2.1.15',
  'bsnAPIfWlanOverride' => '1.3.6.1.4.1.14179.2.2.2.1.16',
  'bsnAPIfPacketsSniffingFeature' => '1.3.6.1.4.1.14179.2.2.2.1.17',
  'bsnAPIfSniffChannel' => '1.3.6.1.4.1.14179.2.2.2.1.18',
  'bsnAPIfSniffServerIPAddress' => '1.3.6.1.4.1.14179.2.2.2.1.19',
  'bsnAPIfAntennaGain' => '1.3.6.1.4.1.14179.2.2.2.1.20',
  'bsnAPIfChannelList' => '1.3.6.1.4.1.14179.2.2.2.1.21',
  'bsnAPIfAbsolutePowerList' => '1.3.6.1.4.1.14179.2.2.2.1.22',
  'bsnAPIfRegulatoryDomainSupport' => '1.3.6.1.4.1.14179.2.2.2.1.23',
  'bsnAPIfAdminStatus' => '1.3.6.1.4.1.14179.2.2.2.1.34',
  'bsnAPIfSmtParamTable' => '1.3.6.1.4.1.14179.2.2.3',
  'bsnAPIfSmtParamEntry' => '1.3.6.1.4.1.14179.2.2.3.1',
  'bsnAPIfDot11BeaconPeriod' => '1.3.6.1.4.1.14179.2.2.3.1.1',
  'bsnAPIfDot11MediumOccupancyLimit' => '1.3.6.1.4.1.14179.2.2.3.1.2',
  'bsnAPIfDot11CFPPeriod' => '1.3.6.1.4.1.14179.2.2.3.1.3',
  'bsnAPIfDot11CFPMaxDuration' => '1.3.6.1.4.1.14179.2.2.3.1.4',
  'bsnAPIfDot11OperationalRateSet' => '1.3.6.1.4.1.14179.2.2.3.1.5',
  'bsnAPIfDot11DTIMPeriod' => '1.3.6.1.4.1.14179.2.2.3.1.6',
  'bsnAPIfDot11MultiDomainCapabilityImplemented' => '1.3.6.1.4.1.14179.2.2.3.1.7',
  'bsnAPIfDot11MultiDomainCapabilityEnabled' => '1.3.6.1.4.1.14179.2.2.3.1.8',
  'bsnAPIfDot11CountryString' => '1.3.6.1.4.1.14179.2.2.3.1.9',
  'bsnAPIfDot11SmtParamsConfigType' => '1.3.6.1.4.1.14179.2.2.3.1.10',
  'bsnAPIfDot11BSSID' => '1.3.6.1.4.1.14179.2.2.3.1.30',
  'bsnAPIfMultiDomainCapabilityTable' => '1.3.6.1.4.1.14179.2.2.4',
  'bsnAPIfMultiDomainCapabilityEntry' => '1.3.6.1.4.1.14179.2.2.4.1',
  'bsnAPIfDot11MaximumTransmitPowerLevel' => '1.3.6.1.4.1.14179.2.2.4.1.1',
  'bsnAPIfDot11FirstChannelNumber' => '1.3.6.1.4.1.14179.2.2.4.1.2',
  'bsnAPIfDot11NumberofChannels' => '1.3.6.1.4.1.14179.2.2.4.1.20',
  'bsnAPIfMacOperationParamTable' => '1.3.6.1.4.1.14179.2.2.5',
  'bsnAPIfMacOperationParamEntry' => '1.3.6.1.4.1.14179.2.2.5.1',
  'bsnAPIfDot11MacRTSThreshold' => '1.3.6.1.4.1.14179.2.2.5.1.1',
  'bsnAPIfDot11MacShortRetryLimit' => '1.3.6.1.4.1.14179.2.2.5.1.2',
  'bsnAPIfDot11MacLongRetryLimit' => '1.3.6.1.4.1.14179.2.2.5.1.3',
  'bsnAPIfDot11MacFragmentationThreshold' => '1.3.6.1.4.1.14179.2.2.5.1.4',
  'bsnAPIfDot11MacMaxTransmitMSDULifetime' => '1.3.6.1.4.1.14179.2.2.5.1.5',
  'bsnAPIfDot11MacParamsConfigType' => '1.3.6.1.4.1.14179.2.2.5.1.6',
  'bsnAPIfDot11MacMaxReceiveLifetime' => '1.3.6.1.4.1.14179.2.2.5.1.25',
  'bsnAPIfDot11CountersTable' => '1.3.6.1.4.1.14179.2.2.6',
  'bsnAPIfDot11CountersEntry' => '1.3.6.1.4.1.14179.2.2.6.1',
  'bsnAPIfDot11TransmittedFragmentCount' => '1.3.6.1.4.1.14179.2.2.6.1.1',
  'bsnAPIfDot11MulticastTransmittedFrameCount' => '1.3.6.1.4.1.14179.2.2.6.1.2',
  'bsnAPIfDot11RetryCount' => '1.3.6.1.4.1.14179.2.2.6.1.3',
  'bsnAPIfDot11MultipleRetryCount' => '1.3.6.1.4.1.14179.2.2.6.1.4',
  'bsnAPIfDot11FrameDuplicateCount' => '1.3.6.1.4.1.14179.2.2.6.1.5',
  'bsnAPIfDot11RTSSuccessCount' => '1.3.6.1.4.1.14179.2.2.6.1.6',
  'bsnAPIfDot11RTSFailureCount' => '1.3.6.1.4.1.14179.2.2.6.1.7',
  'bsnAPIfDot11ACKFailureCount' => '1.3.6.1.4.1.14179.2.2.6.1.8',
  'bsnAPIfDot11ReceivedFragmentCount' => '1.3.6.1.4.1.14179.2.2.6.1.9',
  'bsnAPIfDot11MulticastReceivedFrameCount' => '1.3.6.1.4.1.14179.2.2.6.1.10',
  'bsnAPIfDot11FCSErrorCount' => '1.3.6.1.4.1.14179.2.2.6.1.11',
  'bsnAPIfDot11TransmittedFrameCount' => '1.3.6.1.4.1.14179.2.2.6.1.12',
  'bsnAPIfDot11WEPUndecryptableCount' => '1.3.6.1.4.1.14179.2.2.6.1.13',
  'bsnAPIfDot11FailedCount' => '1.3.6.1.4.1.14179.2.2.6.1.33',
  'bsnAPIfDot11PhyTxPowerTable' => '1.3.6.1.4.1.14179.2.2.8',
  'bsnAPIfDot11PhyTxPowerEntry' => '1.3.6.1.4.1.14179.2.2.8.1',
  'bsnAPIfDot11NumberSupportedPowerLevels' => '1.3.6.1.4.1.14179.2.2.8.1.1',
  'bsnAPIfDot11TxPowerLevel1' => '1.3.6.1.4.1.14179.2.2.8.1.2',
  'bsnAPIfDot11TxPowerLevel2' => '1.3.6.1.4.1.14179.2.2.8.1.3',
  'bsnAPIfDot11TxPowerLevel3' => '1.3.6.1.4.1.14179.2.2.8.1.4',
  'bsnAPIfDot11TxPowerLevel4' => '1.3.6.1.4.1.14179.2.2.8.1.5',
  'bsnAPIfDot11TxPowerLevel5' => '1.3.6.1.4.1.14179.2.2.8.1.6',
  'bsnAPIfDot11TxPowerLevel6' => '1.3.6.1.4.1.14179.2.2.8.1.7',
  'bsnAPIfDot11TxPowerLevel7' => '1.3.6.1.4.1.14179.2.2.8.1.8',
  'bsnAPIfDot11TxPowerLevel8' => '1.3.6.1.4.1.14179.2.2.8.1.28',
  'bsnAPIfDot11PhyChannelTable' => '1.3.6.1.4.1.14179.2.2.9',
  'bsnAPIfDot11PhyChannelEntry' => '1.3.6.1.4.1.14179.2.2.9.1',
  'bsnAPIfDot11CurrentCCAMode' => '1.3.6.1.4.1.14179.2.2.9.1.1',
  'bsnAPIfDot11EDThreshold' => '1.3.6.1.4.1.14179.2.2.9.1.2',
  'bsnAPIfDot11TIThreshold' => '1.3.6.1.4.1.14179.2.2.9.1.23',
  'bsnAPIfProfileThresholdConfigTable' => '1.3.6.1.4.1.14179.2.2.12',
  'bsnAPIfProfileThresholdConfigEntry' => '1.3.6.1.4.1.14179.2.2.12.1',
  'bsnAPIfProfileParamAssignment' => '1.3.6.1.4.1.14179.2.2.12.1.1',
  'bsnAPIfForeignInterferenceThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.2',
  'bsnAPIfForeignNoiseThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.3',
  'bsnAPIfRFUtilizationThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.4',
  'bsnAPIfThroughputThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.5',
  'bsnAPIfMobilesThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.6',
  'bsnAPIfCoverageThreshold' => '1.3.6.1.4.1.14179.2.2.12.1.7',
  'bsnAPIfMobileMinExceptionLevel' => '1.3.6.1.4.1.14179.2.2.12.1.8',
  'bsnAPIfCoverageExceptionLevel' => '1.3.6.1.4.1.14179.2.2.12.1.28',
  'bsnAPIfLoadParametersTable' => '1.3.6.1.4.1.14179.2.2.13',
  'bsnAPIfLoadParametersEntry' => '1.3.6.1.4.1.14179.2.2.13.1',
  'bsnAPIfLoadRxUtilization' => '1.3.6.1.4.1.14179.2.2.13.1.1',
  'bsnAPIfLoadTxUtilization' => '1.3.6.1.4.1.14179.2.2.13.1.2',
  'bsnAPIfLoadChannelUtilization' => '1.3.6.1.4.1.14179.2.2.13.1.3',
  'bsnAPIfLoadNumOfClients' => '1.3.6.1.4.1.14179.2.2.13.1.4',
  'bsnAPIfPoorSNRClients' => '1.3.6.1.4.1.14179.2.2.13.1.24',
  'bsnAPIfChannelInterferenceInfoTable' => '1.3.6.1.4.1.14179.2.2.14',
  'bsnAPIfChannelInterferenceInfoEntry' => '1.3.6.1.4.1.14179.2.2.14.1',
  'bsnAPIfInterferenceChannelNo' => '1.3.6.1.4.1.14179.2.2.14.1.1',
  'bsnAPIfInterferencePower' => '1.3.6.1.4.1.14179.2.2.14.1.2',
  'bsnAPIfInterferenceUtilization' => '1.3.6.1.4.1.14179.2.2.14.1.22',
  'bsnAPIfChannelNoiseInfoTable' => '1.3.6.1.4.1.14179.2.2.15',
  'bsnAPIfChannelNoiseInfoEntry' => '1.3.6.1.4.1.14179.2.2.15.1',
  'bsnAPIfNoiseChannelNo' => '1.3.6.1.4.1.14179.2.2.15.1.1',
  'bsnAPIfDBNoisePower' => '1.3.6.1.4.1.14179.2.2.15.1.21',
  'bsnAPIfProfileStateTable' => '1.3.6.1.4.1.14179.2.2.16',
  'bsnAPIfProfileStateEntry' => '1.3.6.1.4.1.14179.2.2.16.1',
  'bsnAPIfLoadProfileState' => '1.3.6.1.4.1.14179.2.2.16.1.1',
  'bsnAPIfInterferenceProfileState' => '1.3.6.1.4.1.14179.2.2.16.1.2',
  'bsnAPIfNoiseProfileState' => '1.3.6.1.4.1.14179.2.2.16.1.3',
  'bsnAPIfCoverageProfileState' => '1.3.6.1.4.1.14179.2.2.16.1.24',
  'bsnAPIfRxNeighborsTable' => '1.3.6.1.4.1.14179.2.2.17',
  'bsnAPIfRxNeighborsEntry' => '1.3.6.1.4.1.14179.2.2.17.1',
  'bsnAPIfRxNeighborMacAddress' => '1.3.6.1.4.1.14179.2.2.17.1.1',
  'bsnAPIfRxNeighborIpAddress' => '1.3.6.1.4.1.14179.2.2.17.1.2',
  'bsnAPIfRxNeighborRSSI' => '1.3.6.1.4.1.14179.2.2.17.1.3',
  'bsnAPIfRxNeighborSlot' => '1.3.6.1.4.1.14179.2.2.17.1.24',
  'bsnAPIfRxNeighborChannel' => '1.3.6.1.4.1.14179.2.2.17.1.26',
  'bsnAPIfRxNeighborChannelWidth' => '1.3.6.1.4.1.14179.2.2.17.1.27',
  'bsnAPIfStationRSSICoverageInfoTable' => '1.3.6.1.4.1.14179.2.2.18',
  'bsnAPIfStationRSSICoverageInfoEntry' => '1.3.6.1.4.1.14179.2.2.18.1',
  'bsnAPIfStationRSSICoverageIndex' => '1.3.6.1.4.1.14179.2.2.18.1.1',
  'bsnAPIfRSSILevel' => '1.3.6.1.4.1.14179.2.2.18.1.2',
  'bsnAPIfStationCountOnRSSI' => '1.3.6.1.4.1.14179.2.2.18.1.23',
  'bsnAPIfStationSNRCoverageInfoTable' => '1.3.6.1.4.1.14179.2.2.19',
  'bsnAPIfStationSNRCoverageInfoEntry' => '1.3.6.1.4.1.14179.2.2.19.1',
  'bsnAPIfStationSNRCoverageIndex' => '1.3.6.1.4.1.14179.2.2.19.1.1',
  'bsnAPIfSNRLevel' => '1.3.6.1.4.1.14179.2.2.19.1.2',
  'bsnAPIfStationCountOnSNR' => '1.3.6.1.4.1.14179.2.2.19.1.23',
  'bsnAPIfRecommendedRFParametersTable' => '1.3.6.1.4.1.14179.2.2.20',
  'bsnAPIfRecommendedRFParametersEntry' => '1.3.6.1.4.1.14179.2.2.20.1',
  'bsnAPIfRecommendedChannelNumber' => '1.3.6.1.4.1.14179.2.2.20.1.1',
  'bsnAPIfRecommendedTxPowerLevel' => '1.3.6.1.4.1.14179.2.2.20.1.2',
  'bsnAPIfRecommendedRTSThreshold' => '1.3.6.1.4.1.14179.2.2.20.1.3',
  'bsnAPIfRecommendedFragmentationThreshold' => '1.3.6.1.4.1.14179.2.2.20.1.24',
  'bsnAPIfWlanOverrideTable' => '1.3.6.1.4.1.14179.2.2.21',
  'bsnAPIfWlanOverrideEntry' => '1.3.6.1.4.1.14179.2.2.21.1',
  'bsnAPIfWlanOverrideId' => '1.3.6.1.4.1.14179.2.2.21.1.1',
  'bsnAPIfWlanOverrideSsid' => '1.3.6.1.4.1.14179.2.2.21.1.2',
  'bsnAPIfWlanOverrideRowStatus' => '1.3.6.1.4.1.14179.2.2.21.1.15',
  'bsnMeshNodeTable' => '1.3.6.1.4.1.14179.2.2.22',
  'bsnMeshNodeEntry' => '1.3.6.1.4.1.14179.2.2.22.1',
  'bsnMeshNodeRole' => '1.3.6.1.4.1.14179.2.2.22.1.1',
  'bsnMeshNodeGroup' => '1.3.6.1.4.1.14179.2.2.22.1.2',
  'bsnMeshNodeBackhaul' => '1.3.6.1.4.1.14179.2.2.22.1.3',
  'bsnMeshNodeBackhaulPAP' => '1.3.6.1.4.1.14179.2.2.22.1.4',
  'bsnMeshNodeBackhaulRAP' => '1.3.6.1.4.1.14179.2.2.22.1.5',
  'bsnMeshNodeDataRate' => '1.3.6.1.4.1.14179.2.2.22.1.6',
  'bsnMeshNodeChannel' => '1.3.6.1.4.1.14179.2.2.22.1.7',
  'bsnMeshNodeRoutingState' => '1.3.6.1.4.1.14179.2.2.22.1.8',
  'bsnMeshNodeMalformedNeighPackets' => '1.3.6.1.4.1.14179.2.2.22.1.9',
  'bsnMeshNodePoorNeighSnr' => '1.3.6.1.4.1.14179.2.2.22.1.10',
  'bsnMeshNodeBlacklistPackets' => '1.3.6.1.4.1.14179.2.2.22.1.11',
  'bsnMeshNodeInsufficientMemory' => '1.3.6.1.4.1.14179.2.2.22.1.12',
  'bsnMeshNodeRxNeighReq' => '1.3.6.1.4.1.14179.2.2.22.1.13',
  'bsnMeshNodeRxNeighRsp' => '1.3.6.1.4.1.14179.2.2.22.1.14',
  'bsnMeshNodeTxNeighReq' => '1.3.6.1.4.1.14179.2.2.22.1.15',
  'bsnMeshNodeTxNeighRsp' => '1.3.6.1.4.1.14179.2.2.22.1.16',
  'bsnMeshNodeParentChanges' => '1.3.6.1.4.1.14179.2.2.22.1.17',
  'bsnMeshNodeNeighTimeout' => '1.3.6.1.4.1.14179.2.2.22.1.18',
  'bsnMeshNodeParentMacAddress' => '1.3.6.1.4.1.14179.2.2.22.1.19',
  'bsnMeshNodeAPType' => '1.3.6.1.4.1.14179.2.2.22.1.20',
  'bsnMeshNodeEthernetBridge' => '1.3.6.1.4.1.14179.2.2.22.1.21',
  'bsnMeshNodeHops' => '1.3.6.1.4.1.14179.2.2.22.1.30',
  'bsnMeshNeighsTable' => '1.3.6.1.4.1.14179.2.2.23',
  'bsnMeshNeighsEntry' => '1.3.6.1.4.1.14179.2.2.23.1',
  'bsnMeshNeighMacAddress' => '1.3.6.1.4.1.14179.2.2.23.1.1',
  'bsnMeshNeighType' => '1.3.6.1.4.1.14179.2.2.23.1.2',
  'bsnMeshNeighState' => '1.3.6.1.4.1.14179.2.2.23.1.3',
  'bsnMeshNeighSnr' => '1.3.6.1.4.1.14179.2.2.23.1.4',
  'bsnMeshNeighSnrUp' => '1.3.6.1.4.1.14179.2.2.23.1.5',
  'bsnMeshNeighSnrDown' => '1.3.6.1.4.1.14179.2.2.23.1.6',
  'bsnMeshNeighLinkSnr' => '1.3.6.1.4.1.14179.2.2.23.1.7',
  'bsnMeshNeighAdjustedEase' => '1.3.6.1.4.1.14179.2.2.23.1.8',
  'bsnMeshNeighUnadjustedEase' => '1.3.6.1.4.1.14179.2.2.23.1.9',
  'bsnMeshNeighRapEase' => '1.3.6.1.4.1.14179.2.2.23.1.10',
  'bsnMeshNeighTxParent' => '1.3.6.1.4.1.14179.2.2.23.1.11',
  'bsnMeshNeighRxParent' => '1.3.6.1.4.1.14179.2.2.23.1.12',
  'bsnMeshNeighPoorSnr' => '1.3.6.1.4.1.14179.2.2.23.1.13',
  'bsnMeshNeighLastUpdate' => '1.3.6.1.4.1.14179.2.2.23.1.14',
  'bsnMeshNeighParentChange' => '1.3.6.1.4.1.14179.2.2.23.1.20',
  'bsnAPIfRadarChannelStatisticsTable' => '1.3.6.1.4.1.14179.2.2.24',
  'bsnAPIfRadarChannelStatisticsEntry' => '1.3.6.1.4.1.14179.2.2.24.1',
  'bsnAPIfRadarDetectedChannelNumber' => '1.3.6.1.4.1.14179.2.2.24.1.1',
  'bsnAPIfRadarSignalLastHeard' => '1.3.6.1.4.1.14179.2.2.24.1.2',
  'bsnGlobalDot11' => '1.3.6.1.4.1.14179.2.3',
  'bsnGlobalDot11Config' => '1.3.6.1.4.1.14179.2.3.1',
  'bsnGlobalDot11PrivacyOptionImplemented' => '1.3.6.1.4.1.14179.2.3.1.1',
  'bsnGlobalDot11AuthenticationResponseTimeOut' => '1.3.6.1.4.1.14179.2.3.1.2',
  'bsnGlobalDot11MultiDomainCapabilityImplemented' => '1.3.6.1.4.1.14179.2.3.1.3',
  'bsnGlobalDot11MultiDomainCapabilityEnabled' => '1.3.6.1.4.1.14179.2.3.1.4',
  'bsnGlobalDot11CountryIndex' => '1.3.6.1.4.1.14179.2.3.1.5',
  'bsnGlobalDot11LoadBalancing' => '1.3.6.1.4.1.14179.2.3.1.6',
  'bsnGlobalDot11RogueTimer' => '1.3.6.1.4.1.14179.2.3.1.7',
  'bsnPrimaryMwarForAPs' => '1.3.6.1.4.1.14179.2.3.1.8',
  'bsnRtpProtocolPriority' => '1.3.6.1.4.1.14179.2.3.1.9',
  'bsnSystemCurrentTime' => '1.3.6.1.4.1.14179.2.3.1.10',
  'bsnUpdateSystemTime' => '1.3.6.1.4.1.14179.2.3.1.11',
  'bsnOperatingTemperatureEnvironment' => '1.3.6.1.4.1.14179.2.3.1.12',
  'bsnOperatingTemperatureEnvironmentDefinition' => {
    '0' => 'unknown',
    '1' => 'commercial',
    '2' => 'industrial',
  },
  'bsnSensorTemperature' => '1.3.6.1.4.1.14179.2.3.1.13',
  'bsnTemperatureAlarmLowLimit' => '1.3.6.1.4.1.14179.2.3.1.14',
  'bsnTemperatureAlarmHighLimit' => '1.3.6.1.4.1.14179.2.3.1.15',
  'bsnVirtualGatewayAddress' => '1.3.6.1.4.1.14179.2.3.1.16',
  'bsnRFMobilityDomainName' => '1.3.6.1.4.1.14179.2.3.1.17',
  'bsnClientWatchListFeature' => '1.3.6.1.4.1.14179.2.3.1.18',
  'bsnRogueLocationDiscoveryProtocol' => '1.3.6.1.4.1.14179.2.3.1.19',
  'bsnRogueAutoContainFeature' => '1.3.6.1.4.1.14179.2.3.1.20',
  'bsnOverAirProvisionApMode' => '1.3.6.1.4.1.14179.2.3.1.21',
  'bsnMaximumNumberOfConcurrentLogins' => '1.3.6.1.4.1.14179.2.3.1.22',
  'bsnAutoContainRoguesAdvertisingSsid' => '1.3.6.1.4.1.14179.2.3.1.23',
  'bsnAutoContainAdhocNetworks' => '1.3.6.1.4.1.14179.2.3.1.24',
  'bsnAutoContainTrustedClientsOnRogueAps' => '1.3.6.1.4.1.14179.2.3.1.25',
  'bsnValidateRogueClientsAgainstAAA' => '1.3.6.1.4.1.14179.2.3.1.26',
  'bsnSystemTimezoneDelta' => '1.3.6.1.4.1.14179.2.3.1.27',
  'bsnSystemTimezoneDaylightSavings' => '1.3.6.1.4.1.14179.2.3.1.28',
  'bsnAllowAuthorizeApAgainstAAA' => '1.3.6.1.4.1.14179.2.3.1.29',
  'bsnSystemTimezoneDeltaMinutes' => '1.3.6.1.4.1.14179.2.3.1.30',
  'bsnApFallbackEnabled' => '1.3.6.1.4.1.14179.2.3.1.31',
  'bsnAppleTalkEnabled' => '1.3.6.1.4.1.14179.2.3.1.32',
  'bsnTrustedApPolicyConfig' => '1.3.6.1.4.1.14179.2.3.1.40',
  'bsnPolicyForMisconfiguredAps' => '1.3.6.1.4.1.14179.2.3.1.40.1',
  'bsnEncryptionPolicyEnforced' => '1.3.6.1.4.1.14179.2.3.1.40.2',
  'bsnPreamblePolicyEnforced' => '1.3.6.1.4.1.14179.2.3.1.40.3',
  'bsnDot11ModePolicyEnforced' => '1.3.6.1.4.1.14179.2.3.1.40.4',
  'bsnRadioTypePolicyEnforced' => '1.3.6.1.4.1.14179.2.3.1.40.5',
  'bsnValidateSsidForTrustedAp' => '1.3.6.1.4.1.14179.2.3.1.40.6',
  'bsnAlertIfTrustedApMissing' => '1.3.6.1.4.1.14179.2.3.1.40.7',
  'bsnTrustedApEntryExpirationTimeout' => '1.3.6.1.4.1.14179.2.3.1.40.8',
  'bsnClientExclusionPolicyConfig' => '1.3.6.1.4.1.14179.2.3.1.41',
  'bsnExcessive80211AssocFailures' => '1.3.6.1.4.1.14179.2.3.1.41.1',
  'bsnExcessive80211AuthFailures' => '1.3.6.1.4.1.14179.2.3.1.41.2',
  'bsnExcessive8021xAuthFailures' => '1.3.6.1.4.1.14179.2.3.1.41.3',
  'bsnExternalPolicyServerFailures' => '1.3.6.1.4.1.14179.2.3.1.41.4',
  'bsnExcessiveWebAuthFailures' => '1.3.6.1.4.1.14179.2.3.1.41.5',
  'bsnIPTheftORReuse' => '1.3.6.1.4.1.14179.2.3.1.41.6',
  'bsnSignatureConfig' => '1.3.6.1.4.1.14179.2.3.1.42',
  'bsnStandardSignatureTable' => '1.3.6.1.4.1.14179.2.3.1.42.1',
  'bsnStandardSignatureEntry' => '1.3.6.1.4.1.14179.2.3.1.42.1.1',
  'bsnStandardSignaturePrecedence' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.1',
  'bsnStandardSignatureName' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.2',
  'bsnStandardSignatureDescription' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.3',
  'bsnStandardSignatureFrameType' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.4',
  'bsnStandardSignatureAction' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.5',
  'bsnStandardSignatureState' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.6',
  'bsnStandardSignatureFrequency' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.7',
  'bsnStandardSignatureQuietTime' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.8',
  'bsnStandardSignatureVersion' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.9',
  'bsnStandardSignatureConfigType' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.10',
  'bsnStandardSignatureEnable' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.11',
  'bsnStandardSignatureMacInfo' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.12',
  'bsnStandardSignatureMacFreq' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.13',
  'bsnStandardSignatureRowStatus' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.20',
  'bsnStandardSignatureInterval' => '1.3.6.1.4.1.14179.2.3.1.42.1.1.21',
  'bsnStandardSignaturePatternTable' => '1.3.6.1.4.1.14179.2.3.1.42.2',
  'bsnStandardSignaturePatternEntry' => '1.3.6.1.4.1.14179.2.3.1.42.2.1',
  'bsnStandardSignaturePatternIndex' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.1',
  'bsnStandardSignaturePatternOffset' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.2',
  'bsnStandardSignaturePatternString' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.3',
  'bsnStandardSignaturePatternMask' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.4',
  'bsnStandardSignaturePatternOffSetStart' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.5',
  'bsnStandardSignaturePatternRowStatus' => '1.3.6.1.4.1.14179.2.3.1.42.2.1.15',
  'bsnCustomSignatureTable' => '1.3.6.1.4.1.14179.2.3.1.42.3',
  'bsnCustomSignatureEntry' => '1.3.6.1.4.1.14179.2.3.1.42.3.1',
  'bsnCustomSignaturePrecedence' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.1',
  'bsnCustomSignatureName' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.2',
  'bsnCustomSignatureDescription' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.3',
  'bsnCustomSignatureFrameType' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.4',
  'bsnCustomSignatureAction' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.5',
  'bsnCustomSignatureState' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.6',
  'bsnCustomSignatureFrequency' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.7',
  'bsnCustomSignatureQuietTime' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.8',
  'bsnCustomSignatureVersion' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.9',
  'bsnCustomSignatureConfigType' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.10',
  'bsnCustomSignatureEnable' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.11',
  'bsnCustomSignatureMacInfo' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.12',
  'bsnCustomSignatureMacFreq' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.13',
  'bsnCustomSignatureRowStatus' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.20',
  'bsnCustomSignatureInterval' => '1.3.6.1.4.1.14179.2.3.1.42.3.1.21',
  'bsnCustomSignaturePatternTable' => '1.3.6.1.4.1.14179.2.3.1.42.4',
  'bsnCustomSignaturePatternEntry' => '1.3.6.1.4.1.14179.2.3.1.42.4.1',
  'bsnCustomSignaturePatternIndex' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.1',
  'bsnCustomSignaturePatternOffset' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.2',
  'bsnCustomSignaturePatternString' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.3',
  'bsnCustomSignaturePatternMask' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.4',
  'bsnCustomSignaturePatternOffSetStart' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.5',
  'bsnCustomSignaturePatternRowStatus' => '1.3.6.1.4.1.14179.2.3.1.42.4.1.15',
  'bsnSignatureCheckState' => '1.3.6.1.4.1.14179.2.3.1.42.5',
  'bsnRfIdTagConfig' => '1.3.6.1.4.1.14179.2.3.1.43',
  'bsnRfIdTagStatus' => '1.3.6.1.4.1.14179.2.3.1.43.1',
  'bsnRfIdTagDataTimeout' => '1.3.6.1.4.1.14179.2.3.1.43.2',
  'bsnRfIdTagAutoTimeoutStatus' => '1.3.6.1.4.1.14179.2.3.1.43.3',
  'bsnAPNeighborAuthConfig' => '1.3.6.1.4.1.14179.2.3.1.44',
  'bsnAPNeighborAuthStatus' => '1.3.6.1.4.1.14179.2.3.1.44.1',
  'bsnAPNeighborAuthAlarmThreshold' => '1.3.6.1.4.1.14179.2.3.1.44.2',
  'bsnRFNetworkName' => '1.3.6.1.4.1.14179.2.3.1.45',
  'bsnFastSSIDChangeFeature' => '1.3.6.1.4.1.14179.2.3.1.46',
  'bsnBridgingPolicyConfig' => '1.3.6.1.4.1.14179.2.3.1.47',
  'bsnBridgingZeroTouchConfig' => '1.3.6.1.4.1.14179.2.3.1.47.1',
  'bsnBridgingSharedSecretKey' => '1.3.6.1.4.1.14179.2.3.1.47.2',
  'bsnAcceptSelfSignedCertificate' => '1.3.6.1.4.1.14179.2.3.1.48',
  'bsnSystemClockTime' => '1.3.6.1.4.1.14179.2.3.1.49',
  'bsnGlobalDot11b' => '1.3.6.1.4.1.14179.2.3.2',
  'bsnGlobalDot11bConfig' => '1.3.6.1.4.1.14179.2.3.2.1',
  'bsnGlobalDot11bNetworkStatus' => '1.3.6.1.4.1.14179.2.3.2.1.1',
  'bsnGlobalDot11bBeaconPeriod' => '1.3.6.1.4.1.14179.2.3.2.1.2',
  'bsnGlobalDot11bDynamicChannelAssignment' => '1.3.6.1.4.1.14179.2.3.2.1.3',
  'bsnGlobalDot11bCurrentChannel' => '1.3.6.1.4.1.14179.2.3.2.1.4',
  'bsnGlobalDot11bDynamicChannelUpdateInterval' => '1.3.6.1.4.1.14179.2.3.2.1.5',
  'bsnGlobalDot11bInputsForDCA' => '1.3.6.1.4.1.14179.2.3.2.1.6',
  'bsnGlobalDot11bChannelUpdateCmdInvoke' => '1.3.6.1.4.1.14179.2.3.2.1.7',
  'bsnGlobalDot11bChannelUpdateCmdStatus' => '1.3.6.1.4.1.14179.2.3.2.1.8',
  'bsnGlobalDot11bDynamicTransmitPowerControl' => '1.3.6.1.4.1.14179.2.3.2.1.9',
  'bsnGlobalDot11bDynamicTxPowerControlInterval' => '1.3.6.1.4.1.14179.2.3.2.1.10',
  'bsnGlobalDot11bCurrentTxPowerLevel' => '1.3.6.1.4.1.14179.2.3.2.1.11',
  'bsnGlobalDot11bInputsForDTP' => '1.3.6.1.4.1.14179.2.3.2.1.12',
  'bsnGlobalDot11bPowerUpdateCmdInvoke' => '1.3.6.1.4.1.14179.2.3.2.1.13',
  'bsnGlobalDot11bPowerUpdateCmdStatus' => '1.3.6.1.4.1.14179.2.3.2.1.14',
  'bsnGlobalDot11bDataRate1Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.15',
  'bsnGlobalDot11bDataRate2Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.16',
  'bsnGlobalDot11bDataRate5AndHalfMhz' => '1.3.6.1.4.1.14179.2.3.2.1.17',
  'bsnGlobalDot11bDataRate11Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.18',
  'bsnGlobalDot11bShortPreamble' => '1.3.6.1.4.1.14179.2.3.2.1.19',
  'bsnGlobalDot11bDot11gSupport' => '1.3.6.1.4.1.14179.2.3.2.1.20',
  'bsnGlobalDot11bDataRate6Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.21',
  'bsnGlobalDot11bDataRate9Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.22',
  'bsnGlobalDot11bDataRate12Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.23',
  'bsnGlobalDot11bDataRate18Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.24',
  'bsnGlobalDot11bDataRate24Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.25',
  'bsnGlobalDot11bDataRate36Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.26',
  'bsnGlobalDot11bDataRate48Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.27',
  'bsnGlobalDot11bDataRate54Mhz' => '1.3.6.1.4.1.14179.2.3.2.1.28',
  'bsnGlobalDot11bPicoCellMode' => '1.3.6.1.4.1.14179.2.3.2.1.29',
  'bsnGlobalDot11bFastRoamingMode' => '1.3.6.1.4.1.14179.2.3.2.1.30',
  'bsnGlobalDot11bFastRoamingVoipMinRate' => '1.3.6.1.4.1.14179.2.3.2.1.31',
  'bsnGlobalDot11bFastRoamingVoipPercentage' => '1.3.6.1.4.1.14179.2.3.2.1.32',
  'bsnGlobalDot11b80211eMaxBandwidth' => '1.3.6.1.4.1.14179.2.3.2.1.33',
  'bsnGlobalDot11bDTPCSupport' => '1.3.6.1.4.1.14179.2.3.2.1.34',
  'bsnGlobalDot11bPhy' => '1.3.6.1.4.1.14179.2.3.2.2',
  'bsnGlobalDot11bMediumOccupancyLimit' => '1.3.6.1.4.1.14179.2.3.2.2.1',
  'bsnGlobalDot11bCFPPeriod' => '1.3.6.1.4.1.14179.2.3.2.2.2',
  'bsnGlobalDot11bCFPMaxDuration' => '1.3.6.1.4.1.14179.2.3.2.2.3',
  'bsnGlobalDot11bCFPollable' => '1.3.6.1.4.1.14179.2.3.2.2.5',
  'bsnGlobalDot11bCFPollRequest' => '1.3.6.1.4.1.14179.2.3.2.2.6',
  'bsnGlobalDot11bDTIMPeriod' => '1.3.6.1.4.1.14179.2.3.2.2.7',
  'bsnGlobalDot11bMaximumTransmitPowerLevel' => '1.3.6.1.4.1.14179.2.3.2.2.8',
  'bsnGlobalDot11bFirstChannelNumber' => '1.3.6.1.4.1.14179.2.3.2.2.9',
  'bsnGlobalDot11bNumberofChannels' => '1.3.6.1.4.1.14179.2.3.2.2.10',
  'bsnGlobalDot11bRTSThreshold' => '1.3.6.1.4.1.14179.2.3.2.2.11',
  'bsnGlobalDot11bShortRetryLimit' => '1.3.6.1.4.1.14179.2.3.2.2.12',
  'bsnGlobalDot11bLongRetryLimit' => '1.3.6.1.4.1.14179.2.3.2.2.13',
  'bsnGlobalDot11bFragmentationThreshold' => '1.3.6.1.4.1.14179.2.3.2.2.14',
  'bsnGlobalDot11bMaxTransmitMSDULifetime' => '1.3.6.1.4.1.14179.2.3.2.2.15',
  'bsnGlobalDot11bMaxReceiveLifetime' => '1.3.6.1.4.1.14179.2.3.2.2.16',
  'bsnGlobalDot11bEDThreshold' => '1.3.6.1.4.1.14179.2.3.2.2.17',
  'bsnGlobalDot11bChannelAgilityEnabled' => '1.3.6.1.4.1.14179.2.3.2.2.18',
  'bsnGlobalDot11bPBCCOptionImplemented' => '1.3.6.1.4.1.14179.2.3.2.2.19',
  'bsnGlobalDot11bShortPreambleOptionImplemented' => '1.3.6.1.4.1.14179.2.3.2.2.20',
  'bsnGlobalDot11a' => '1.3.6.1.4.1.14179.2.3.3',
  'bsnGlobalDot11aConfig' => '1.3.6.1.4.1.14179.2.3.3.1',
  'bsnGlobalDot11aNetworkStatus' => '1.3.6.1.4.1.14179.2.3.3.1.1',
  'bsnGlobalDot11aLowBandNetwork' => '1.3.6.1.4.1.14179.2.3.3.1.2',
  'bsnGlobalDot11aMediumBandNetwork' => '1.3.6.1.4.1.14179.2.3.3.1.3',
  'bsnGlobalDot11aHighBandNetwork' => '1.3.6.1.4.1.14179.2.3.3.1.4',
  'bsnGlobalDot11aBeaconPeriod' => '1.3.6.1.4.1.14179.2.3.3.1.5',
  'bsnGlobalDot11aDynamicChannelAssignment' => '1.3.6.1.4.1.14179.2.3.3.1.6',
  'bsnGlobalDot11aCurrentChannel' => '1.3.6.1.4.1.14179.2.3.3.1.7',
  'bsnGlobalDot11aDynamicChannelUpdateInterval' => '1.3.6.1.4.1.14179.2.3.3.1.8',
  'bsnGlobalDot11aInputsForDCA' => '1.3.6.1.4.1.14179.2.3.3.1.9',
  'bsnGlobalDot11aChannelUpdateCmdInvoke' => '1.3.6.1.4.1.14179.2.3.3.1.10',
  'bsnGlobalDot11aChannelUpdateCmdStatus' => '1.3.6.1.4.1.14179.2.3.3.1.11',
  'bsnGlobalDot11aDynamicTransmitPowerControl' => '1.3.6.1.4.1.14179.2.3.3.1.12',
  'bsnGlobalDot11aCurrentTxPowerLevel' => '1.3.6.1.4.1.14179.2.3.3.1.13',
  'bsnGlobalDot11aDynamicTxPowerControlInterval' => '1.3.6.1.4.1.14179.2.3.3.1.14',
  'bsnGlobalDot11aInputsForDTP' => '1.3.6.1.4.1.14179.2.3.3.1.15',
  'bsnGlobalDot11aPowerUpdateCmdInvoke' => '1.3.6.1.4.1.14179.2.3.3.1.16',
  'bsnGlobalDot11aPowerUpdateCmdStatus' => '1.3.6.1.4.1.14179.2.3.3.1.17',
  'bsnGlobalDot11aDataRate6Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.19',
  'bsnGlobalDot11aDataRate9Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.20',
  'bsnGlobalDot11aDataRate12Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.21',
  'bsnGlobalDot11aDataRate18Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.22',
  'bsnGlobalDot11aDataRate24Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.23',
  'bsnGlobalDot11aDataRate36Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.24',
  'bsnGlobalDot11aDataRate48Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.25',
  'bsnGlobalDot11aDataRate54Mhz' => '1.3.6.1.4.1.14179.2.3.3.1.26',
  'bsnGlobalDot11aPicoCellMode' => '1.3.6.1.4.1.14179.2.3.3.1.27',
  'bsnGlobalDot11aFastRoamingMode' => '1.3.6.1.4.1.14179.2.3.3.1.28',
  'bsnGlobalDot11aFastRoamingVoipMinRate' => '1.3.6.1.4.1.14179.2.3.3.1.29',
  'bsnGlobalDot11aFastRoamingVoipPercentage' => '1.3.6.1.4.1.14179.2.3.3.1.30',
  'bsnGlobalDot11a80211eMaxBandwidth' => '1.3.6.1.4.1.14179.2.3.3.1.31',
  'bsnGlobalDot11aDTPCSupport' => '1.3.6.1.4.1.14179.2.3.3.1.32',
  'bsnGlobalDot11aPhy' => '1.3.6.1.4.1.14179.2.3.3.2',
  'bsnGlobalDot11aMediumOccupancyLimit' => '1.3.6.1.4.1.14179.2.3.3.2.1',
  'bsnGlobalDot11aCFPPeriod' => '1.3.6.1.4.1.14179.2.3.3.2.2',
  'bsnGlobalDot11aCFPMaxDuration' => '1.3.6.1.4.1.14179.2.3.3.2.3',
  'bsnGlobalDot11aCFPollable' => '1.3.6.1.4.1.14179.2.3.3.2.5',
  'bsnGlobalDot11aCFPollRequest' => '1.3.6.1.4.1.14179.2.3.3.2.6',
  'bsnGlobalDot11aDTIMPeriod' => '1.3.6.1.4.1.14179.2.3.3.2.7',
  'bsnGlobalDot11aMaximumTransmitPowerLevel' => '1.3.6.1.4.1.14179.2.3.3.2.8',
  'bsnGlobalDot11aFirstChannelNumber' => '1.3.6.1.4.1.14179.2.3.3.2.9',
  'bsnGlobalDot11aNumberofChannels' => '1.3.6.1.4.1.14179.2.3.3.2.10',
  'bsnGlobalDot11aRTSThreshold' => '1.3.6.1.4.1.14179.2.3.3.2.11',
  'bsnGlobalDot11aShortRetryLimit' => '1.3.6.1.4.1.14179.2.3.3.2.12',
  'bsnGlobalDot11aLongRetryLimit' => '1.3.6.1.4.1.14179.2.3.3.2.13',
  'bsnGlobalDot11aFragmentationThreshold' => '1.3.6.1.4.1.14179.2.3.3.2.14',
  'bsnGlobalDot11aMaxTransmitMSDULifetime' => '1.3.6.1.4.1.14179.2.3.3.2.15',
  'bsnGlobalDot11aMaxReceiveLifetime' => '1.3.6.1.4.1.14179.2.3.3.2.16',
  'bsnGlobalDot11aTIThreshold' => '1.3.6.1.4.1.14179.2.3.3.2.17',
  'bsnGlobalDot11aChannelAgilityEnabled' => '1.3.6.1.4.1.14179.2.3.3.2.18',
  'bsnGlobalDot11h' => '1.3.6.1.4.1.14179.2.3.4',
  'bsnGlobalDot11hConfig' => '1.3.6.1.4.1.14179.2.3.4.1',
  'bsnGlobalDot11hPowerConstraint' => '1.3.6.1.4.1.14179.2.3.4.1.1',
  'bsnGlobalDot11hChannelSwitchEnable' => '1.3.6.1.4.1.14179.2.3.4.1.2',
  'bsnGlobalDot11hChannelSwitchMode' => '1.3.6.1.4.1.14179.2.3.4.1.3',
  'bsnRrm' => '1.3.6.1.4.1.14179.2.4',
  'bsnRrmDot11a' => '1.3.6.1.4.1.14179.2.4.1',
  'bsnRrmDot11aGroup' => '1.3.6.1.4.1.14179.2.4.1.1',
  'bsnRrmDot11aGlobalAutomaticGrouping' => '1.3.6.1.4.1.14179.2.4.1.1.1',
  'bsnRrmDot11aGroupLeaderMacAddr' => '1.3.6.1.4.1.14179.2.4.1.1.2',
  'bsnRrmIsDot11aGroupLeader' => '1.3.6.1.4.1.14179.2.4.1.1.3',
  'bsnRrmDot11aGroupLastUpdateTime' => '1.3.6.1.4.1.14179.2.4.1.1.4',
  'bsnRrmDot11aGlobalGroupInterval' => '1.3.6.1.4.1.14179.2.4.1.1.5',
  'bsnWrasDot11aGroupTable' => '1.3.6.1.4.1.14179.2.4.1.1.9',
  'bsnWrasDot11aGroupEntry' => '1.3.6.1.4.1.14179.2.4.1.1.9.1',
  'bsnWrasDot11aPeerMacAddress' => '1.3.6.1.4.1.14179.2.4.1.1.9.1.1',
  'bsnWrasDot11aPeerIpAddress' => '1.3.6.1.4.1.14179.2.4.1.1.9.1.21',
  'bsnRrmDot11aAPDefault' => '1.3.6.1.4.1.14179.2.4.1.6',
  'bsnRrmDot11aForeignInterferenceThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.1',
  'bsnRrmDot11aForeignNoiseThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.2',
  'bsnRrmDot11aRFUtilizationThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.3',
  'bsnRrmDot11aThroughputThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.4',
  'bsnRrmDot11aMobilesThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.5',
  'bsnRrmDot11aCoverageThreshold' => '1.3.6.1.4.1.14179.2.4.1.6.6',
  'bsnRrmDot11aMobileMinExceptionLevel' => '1.3.6.1.4.1.14179.2.4.1.6.7',
  'bsnRrmDot11aCoverageExceptionLevel' => '1.3.6.1.4.1.14179.2.4.1.6.8',
  'bsnRrmDot11aSignalMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.1.6.9',
  'bsnRrmDot11aNoiseMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.1.6.10',
  'bsnRrmDot11aLoadMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.1.6.11',
  'bsnRrmDot11aCoverageMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.1.6.12',
  'bsnRrmDot11aChannelMonitorList' => '1.3.6.1.4.1.14179.2.4.1.6.13',
  'bsnRrmDot11aSetFactoryDefault' => '1.3.6.1.4.1.14179.2.4.1.7',
  'bsnRrmDot11b' => '1.3.6.1.4.1.14179.2.4.2',
  'bsnRrmDot11bGroup' => '1.3.6.1.4.1.14179.2.4.2.1',
  'bsnRrmDot11bGlobalAutomaticGrouping' => '1.3.6.1.4.1.14179.2.4.2.1.1',
  'bsnRrmDot11bGroupLeaderMacAddr' => '1.3.6.1.4.1.14179.2.4.2.1.2',
  'bsnRrmIsDot11bGroupLeader' => '1.3.6.1.4.1.14179.2.4.2.1.3',
  'bsnRrmDot11bGroupLastUpdateTime' => '1.3.6.1.4.1.14179.2.4.2.1.4',
  'bsnRrmDot11bGlobalGroupInterval' => '1.3.6.1.4.1.14179.2.4.2.1.5',
  'bsnWrasDot11bGroupTable' => '1.3.6.1.4.1.14179.2.4.2.1.9',
  'bsnWrasDot11bGroupEntry' => '1.3.6.1.4.1.14179.2.4.2.1.9.1',
  'bsnWrasDot11bPeerMacAddress' => '1.3.6.1.4.1.14179.2.4.2.1.9.1.1',
  'bsnWrasDot11bPeerIpAddress' => '1.3.6.1.4.1.14179.2.4.2.1.9.1.21',
  'bsnRrmDot11bAPDefault' => '1.3.6.1.4.1.14179.2.4.2.6',
  'bsnRrmDot11bForeignInterferenceThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.1',
  'bsnRrmDot11bForeignNoiseThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.2',
  'bsnRrmDot11bRFUtilizationThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.3',
  'bsnRrmDot11bThroughputThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.4',
  'bsnRrmDot11bMobilesThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.5',
  'bsnRrmDot11bCoverageThreshold' => '1.3.6.1.4.1.14179.2.4.2.6.6',
  'bsnRrmDot11bMobileMinExceptionLevel' => '1.3.6.1.4.1.14179.2.4.2.6.7',
  'bsnRrmDot11bCoverageExceptionLevel' => '1.3.6.1.4.1.14179.2.4.2.6.8',
  'bsnRrmDot11bSignalMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.2.6.9',
  'bsnRrmDot11bNoiseMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.2.6.10',
  'bsnRrmDot11bLoadMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.2.6.11',
  'bsnRrmDot11bCoverageMeasurementInterval' => '1.3.6.1.4.1.14179.2.4.2.6.12',
  'bsnRrmDot11bChannelMonitorList' => '1.3.6.1.4.1.14179.2.4.2.6.13',
  'bsnRrmDot11bSetFactoryDefault' => '1.3.6.1.4.1.14179.2.4.2.7',
  'bsnAAA' => '1.3.6.1.4.1.14179.2.5',
  'bsnRadiusAuthServerTable' => '1.3.6.1.4.1.14179.2.5.1',
  'bsnRadiusAuthServerEntry' => '1.3.6.1.4.1.14179.2.5.1.1',
  'bsnRadiusAuthServerIndex' => '1.3.6.1.4.1.14179.2.5.1.1.1',
  'bsnRadiusAuthServerAddress' => '1.3.6.1.4.1.14179.2.5.1.1.2',
  'bsnRadiusAuthClientServerPortNumber' => '1.3.6.1.4.1.14179.2.5.1.1.3',
  'bsnRadiusAuthServerKey' => '1.3.6.1.4.1.14179.2.5.1.1.4',
  'bsnRadiusAuthServerStatus' => '1.3.6.1.4.1.14179.2.5.1.1.5',
  'bsnRadiusAuthServerKeyFormat' => '1.3.6.1.4.1.14179.2.5.1.1.6',
  'bsnRadiusAuthServerRFC3576' => '1.3.6.1.4.1.14179.2.5.1.1.7',
  'bsnRadiusAuthServerIPSec' => '1.3.6.1.4.1.14179.2.5.1.1.8',
  'bsnRadiusAuthServerIPSecAuth' => '1.3.6.1.4.1.14179.2.5.1.1.9',
  'bsnRadiusAuthServerIPSecEncryption' => '1.3.6.1.4.1.14179.2.5.1.1.10',
  'bsnRadiusAuthServerIPSecIKEPhase1' => '1.3.6.1.4.1.14179.2.5.1.1.11',
  'bsnRadiusAuthServerIPSecIKELifetime' => '1.3.6.1.4.1.14179.2.5.1.1.12',
  'bsnRadiusAuthServerIPSecDHGroup' => '1.3.6.1.4.1.14179.2.5.1.1.13',
  'bsnRadiusAuthServerNetworkUserConfig' => '1.3.6.1.4.1.14179.2.5.1.1.14',
  'bsnRadiusAuthServerMgmtUserConfig' => '1.3.6.1.4.1.14179.2.5.1.1.15',
  'bsnRadiusAuthServerRetransmitTimeout' => '1.3.6.1.4.1.14179.2.5.1.1.17',
  'bsnRadiusAuthServerKeyWrapKEKkey' => '1.3.6.1.4.1.14179.2.5.1.1.18',
  'bsnRadiusAuthServerKeyWrapMACKkey' => '1.3.6.1.4.1.14179.2.5.1.1.19',
  'bsnRadiusAuthServerKeyWrapFormat' => '1.3.6.1.4.1.14179.2.5.1.1.20',
  'bsnRadiusAuthServerRowStatus' => '1.3.6.1.4.1.14179.2.5.1.1.26',
  'bsnRadiusAccServerTable' => '1.3.6.1.4.1.14179.2.5.2',
  'bsnRadiusAccServerEntry' => '1.3.6.1.4.1.14179.2.5.2.1',
  'bsnRadiusAccServerIndex' => '1.3.6.1.4.1.14179.2.5.2.1.1',
  'bsnRadiusAccServerAddress' => '1.3.6.1.4.1.14179.2.5.2.1.2',
  'bsnRadiusAccClientServerPortNumber' => '1.3.6.1.4.1.14179.2.5.2.1.3',
  'bsnRadiusAccServerKey' => '1.3.6.1.4.1.14179.2.5.2.1.4',
  'bsnRadiusAccServerStatus' => '1.3.6.1.4.1.14179.2.5.2.1.5',
  'bsnRadiusAccServerKeyFormat' => '1.3.6.1.4.1.14179.2.5.2.1.6',
  'bsnRadiusAccServerIPSec' => '1.3.6.1.4.1.14179.2.5.2.1.7',
  'bsnRadiusAccServerIPSecAuth' => '1.3.6.1.4.1.14179.2.5.2.1.8',
  'bsnRadiusAccServerIPSecEncryption' => '1.3.6.1.4.1.14179.2.5.2.1.9',
  'bsnRadiusAccServerIPSecIKEPhase1' => '1.3.6.1.4.1.14179.2.5.2.1.10',
  'bsnRadiusAccServerIPSecIKELifetime' => '1.3.6.1.4.1.14179.2.5.2.1.11',
  'bsnRadiusAccServerIPSecDHGroup' => '1.3.6.1.4.1.14179.2.5.2.1.12',
  'bsnRadiusAccServerNetworkUserConfig' => '1.3.6.1.4.1.14179.2.5.2.1.13',
  'bsnRadiusAccServerRetransmitTimeout' => '1.3.6.1.4.1.14179.2.5.2.1.14',
  'bsnRadiusAccServerRowStatus' => '1.3.6.1.4.1.14179.2.5.2.1.26',
  'bsnRadiusAuthServerStatsTable' => '1.3.6.1.4.1.14179.2.5.3',
  'bsnRadiusAuthServerStatsEntry' => '1.3.6.1.4.1.14179.2.5.3.1',
  'bsnRadiusAuthClientRoundTripTime' => '1.3.6.1.4.1.14179.2.5.3.1.6',
  'bsnRadiusAuthClientAccessRequests' => '1.3.6.1.4.1.14179.2.5.3.1.7',
  'bsnRadiusAuthClientAccessRetransmissions' => '1.3.6.1.4.1.14179.2.5.3.1.8',
  'bsnRadiusAuthClientAccessAccepts' => '1.3.6.1.4.1.14179.2.5.3.1.9',
  'bsnRadiusAuthClientAccessRejects' => '1.3.6.1.4.1.14179.2.5.3.1.10',
  'bsnRadiusAuthClientAccessChallenges' => '1.3.6.1.4.1.14179.2.5.3.1.11',
  'bsnRadiusAuthClientMalformedAccessResponses' => '1.3.6.1.4.1.14179.2.5.3.1.12',
  'bsnRadiusAuthClientBadAuthenticators' => '1.3.6.1.4.1.14179.2.5.3.1.13',
  'bsnRadiusAuthClientPendingRequests' => '1.3.6.1.4.1.14179.2.5.3.1.14',
  'bsnRadiusAuthClientTimeouts' => '1.3.6.1.4.1.14179.2.5.3.1.15',
  'bsnRadiusAuthClientUnknownTypes' => '1.3.6.1.4.1.14179.2.5.3.1.16',
  'bsnRadiusAuthClientPacketsDropped' => '1.3.6.1.4.1.14179.2.5.3.1.36',
  'bsnRadiusAccServerStatsTable' => '1.3.6.1.4.1.14179.2.5.4',
  'bsnRadiusAccServerStatsEntry' => '1.3.6.1.4.1.14179.2.5.4.1',
  'bsnRadiusAccClientRoundTripTime' => '1.3.6.1.4.1.14179.2.5.4.1.6',
  'bsnRadiusAccClientRequests' => '1.3.6.1.4.1.14179.2.5.4.1.7',
  'bsnRadiusAccClientRetransmissions' => '1.3.6.1.4.1.14179.2.5.4.1.8',
  'bsnRadiusAccClientResponses' => '1.3.6.1.4.1.14179.2.5.4.1.9',
  'bsnRadiusAccClientMalformedResponses' => '1.3.6.1.4.1.14179.2.5.4.1.10',
  'bsnRadiusAccClientBadAuthenticators' => '1.3.6.1.4.1.14179.2.5.4.1.11',
  'bsnRadiusAccClientPendingRequests' => '1.3.6.1.4.1.14179.2.5.4.1.12',
  'bsnRadiusAccClientTimeouts' => '1.3.6.1.4.1.14179.2.5.4.1.13',
  'bsnRadiusAccClientUnknownTypes' => '1.3.6.1.4.1.14179.2.5.4.1.14',
  'bsnRadiusAccClientPacketsDropped' => '1.3.6.1.4.1.14179.2.5.4.1.34',
  'bsnUsersTable' => '1.3.6.1.4.1.14179.2.5.5',
  'bsnUsersEntry' => '1.3.6.1.4.1.14179.2.5.5.1',
  'bsnUserName' => '1.3.6.1.4.1.14179.2.5.5.1.2',
  'bsnUserPassword' => '1.3.6.1.4.1.14179.2.5.5.1.3',
  'bsnUserEssIndex' => '1.3.6.1.4.1.14179.2.5.5.1.4',
  'bsnUserAccessMode' => '1.3.6.1.4.1.14179.2.5.5.1.5',
  'bsnUserType' => '1.3.6.1.4.1.14179.2.5.5.1.6',
  'bsnUserInterfaceName' => '1.3.6.1.4.1.14179.2.5.5.1.7',
  'bsnUserRowStatus' => '1.3.6.1.4.1.14179.2.5.5.1.26',
  'bsnBlackListClientTable' => '1.3.6.1.4.1.14179.2.5.6',
  'bsnBlackListClientEntry' => '1.3.6.1.4.1.14179.2.5.6.1',
  'bsnBlackListClientMacAddress' => '1.3.6.1.4.1.14179.2.5.6.1.1',
  'bsnBlackListClientDescription' => '1.3.6.1.4.1.14179.2.5.6.1.2',
  'bsnBlackListClientRowStatus' => '1.3.6.1.4.1.14179.2.5.6.1.22',
  'bsnAclTable' => '1.3.6.1.4.1.14179.2.5.7',
  'bsnAclEntry' => '1.3.6.1.4.1.14179.2.5.7.1',
  'bsnAclName' => '1.3.6.1.4.1.14179.2.5.7.1.1',
  'bsnAclApplyMode' => '1.3.6.1.4.1.14179.2.5.7.1.2',
  'bsnAclRowStatus' => '1.3.6.1.4.1.14179.2.5.7.1.20',
  'bsnAclRuleTable' => '1.3.6.1.4.1.14179.2.5.8',
  'bsnAclRuleEntry' => '1.3.6.1.4.1.14179.2.5.8.1',
  'bsnAclRuleIndex' => '1.3.6.1.4.1.14179.2.5.8.1.2',
  'bsnAclRuleAction' => '1.3.6.1.4.1.14179.2.5.8.1.3',
  'bsnAclRuleDirection' => '1.3.6.1.4.1.14179.2.5.8.1.4',
  'bsnAclRuleSourceIpAddress' => '1.3.6.1.4.1.14179.2.5.8.1.5',
  'bsnAclRuleSourceIpNetmask' => '1.3.6.1.4.1.14179.2.5.8.1.6',
  'bsnAclRuleDestinationIpAddress' => '1.3.6.1.4.1.14179.2.5.8.1.7',
  'bsnAclRuleDestinationIpNetmask' => '1.3.6.1.4.1.14179.2.5.8.1.8',
  'bsnAclRuleProtocol' => '1.3.6.1.4.1.14179.2.5.8.1.9',
  'bsnAclRuleStartSourcePort' => '1.3.6.1.4.1.14179.2.5.8.1.10',
  'bsnAclRuleEndSourcePort' => '1.3.6.1.4.1.14179.2.5.8.1.11',
  'bsnAclRuleStartDestinationPort' => '1.3.6.1.4.1.14179.2.5.8.1.12',
  'bsnAclRuleEndDestinationPort' => '1.3.6.1.4.1.14179.2.5.8.1.13',
  'bsnAclRuleDscp' => '1.3.6.1.4.1.14179.2.5.8.1.14',
  'bsnAclNewRuleIndex' => '1.3.6.1.4.1.14179.2.5.8.1.15',
  'bsnAclRuleRowStatus' => '1.3.6.1.4.1.14179.2.5.8.1.40',
  'bsnMacFilterTable' => '1.3.6.1.4.1.14179.2.5.9',
  'bsnMacFilterEntry' => '1.3.6.1.4.1.14179.2.5.9.1',
  'bsnMacFilterAddress' => '1.3.6.1.4.1.14179.2.5.9.1.1',
  'bsnMacFilterWlanId' => '1.3.6.1.4.1.14179.2.5.9.1.2',
  'bsnMacFilterInterfaceName' => '1.3.6.1.4.1.14179.2.5.9.1.3',
  'bsnMacFilterDescription' => '1.3.6.1.4.1.14179.2.5.9.1.4',
  'bsnMacFilterRowStatus' => '1.3.6.1.4.1.14179.2.5.9.1.24',
  'bsnLocalNetUserTable' => '1.3.6.1.4.1.14179.2.5.10',
  'bsnLocalNetUserEntry' => '1.3.6.1.4.1.14179.2.5.10.1',
  'bsnLocalNetUserName' => '1.3.6.1.4.1.14179.2.5.10.1.1',
  'bsnLocalNetUserWlanId' => '1.3.6.1.4.1.14179.2.5.10.1.2',
  'bsnLocalNetUserPassword' => '1.3.6.1.4.1.14179.2.5.10.1.3',
  'bsnLocalNetUserDescription' => '1.3.6.1.4.1.14179.2.5.10.1.4',
  'bsnLocalNetUserLifetime' => '1.3.6.1.4.1.14179.2.5.10.1.5',
  'bsnLocalNetUserStartTime' => '1.3.6.1.4.1.14179.2.5.10.1.6',
  'bsnLocalNetUserRemainingTime' => '1.3.6.1.4.1.14179.2.5.10.1.7',
  'bsnLocalNetUserRowStatus' => '1.3.6.1.4.1.14179.2.5.10.1.24',
  'bsnLocalManagementUserTable' => '1.3.6.1.4.1.14179.2.5.11',
  'bsnLocalManagementUserEntry' => '1.3.6.1.4.1.14179.2.5.11.1',
  'bsnLocalManagementUserName' => '1.3.6.1.4.1.14179.2.5.11.1.1',
  'bsnLocalManagementUserPassword' => '1.3.6.1.4.1.14179.2.5.11.1.2',
  'bsnLocalManagementUserAccessMode' => '1.3.6.1.4.1.14179.2.5.11.1.3',
  'bsnLocalManagementUserRowStatus' => '1.3.6.1.4.1.14179.2.5.11.1.23',
  'bsnRadiusAuthKeyWrapEnable' => '1.3.6.1.4.1.14179.2.5.12',
  'bsnRadiusAuthCacheCredentialsLocally' => '1.3.6.1.4.1.14179.2.5.14',
  'bsnAAAMacDelimiter' => '1.3.6.1.4.1.14179.2.5.15',
  'bsnAAARadiusCompatibilityMode' => '1.3.6.1.4.1.14179.2.5.16',
  'bsnAAARadiusCallStationIdType' => '1.3.6.1.4.1.14179.2.5.17',
  'bsnExternalPolicyServerAclName' => '1.3.6.1.4.1.14179.2.5.18',
  'bsnExternalPolicyServerTable' => '1.3.6.1.4.1.14179.2.5.19',
  'bsnExternalPolicyServerEntry' => '1.3.6.1.4.1.14179.2.5.19.1',
  'bsnExternalPolicyServerIndex' => '1.3.6.1.4.1.14179.2.5.19.1.1',
  'bsnExternalPolicyServerAddress' => '1.3.6.1.4.1.14179.2.5.19.1.2',
  'bsnExternalPolicyServerPortNumber' => '1.3.6.1.4.1.14179.2.5.19.1.3',
  'bsnExternalPolicyServerKey' => '1.3.6.1.4.1.14179.2.5.19.1.4',
  'bsnExternalPolicyServerAdminStatus' => '1.3.6.1.4.1.14179.2.5.19.1.5',
  'bsnExternalPolicyServerConnectionStatus' => '1.3.6.1.4.1.14179.2.5.19.1.6',
  'bsnExternalPolicyServerRowStatus' => '1.3.6.1.4.1.14179.2.5.19.1.26',
  'bsnAAALocalDatabaseSize' => '1.3.6.1.4.1.14179.2.5.20',
  'bsnAAACurrentLocalDatabaseSize' => '1.3.6.1.4.1.14179.2.5.21',
  'bsnAPAuthorizationTable' => '1.3.6.1.4.1.14179.2.5.22',
  'bsnAPAuthorizationEntry' => '1.3.6.1.4.1.14179.2.5.22.1',
  'bsnAPAuthMacAddress' => '1.3.6.1.4.1.14179.2.5.22.1.1',
  'bsnAPAuthCertificateType' => '1.3.6.1.4.1.14179.2.5.22.1.2',
  'bsnAPAuthHashKey' => '1.3.6.1.4.1.14179.2.5.22.1.3',
  'bsnAPAuthRowStatus' => '1.3.6.1.4.1.14179.2.5.22.1.20',
  'bsnTrap' => '1.3.6.1.4.1.14179.2.6',
  'bsnTrapControl' => '1.3.6.1.4.1.14179.2.6.1',
  'bsnDot11StationTrapControlMask' => '1.3.6.1.4.1.14179.2.6.1.1',
  'bsnAPTrapControlMask' => '1.3.6.1.4.1.14179.2.6.1.2',
  'bsnAPProfileTrapControlMask' => '1.3.6.1.4.1.14179.2.6.1.3',
  'bsnAPParamUpdateTrapControlMask' => '1.3.6.1.4.1.14179.2.6.1.4',
  'bsnIpsecTrapsMask' => '1.3.6.1.4.1.14179.2.6.1.5',
  'bsnRogueAPTrapEnable' => '1.3.6.1.4.1.14179.2.6.1.6',
  'bsnRADIUSServerTrapEnable' => '1.3.6.1.4.1.14179.2.6.1.7',
  'bsnAuthenticationFailureTrapEnable' => '1.3.6.1.4.1.14179.2.6.1.8',
  'bsnConfigSaveTrapEnable' => '1.3.6.1.4.1.14179.2.6.1.9',
  'bsn80211SecurityTrapControlMask' => '1.3.6.1.4.1.14179.2.6.1.10',
  'bsnWpsTrapControlEnable' => '1.3.6.1.4.1.14179.2.6.1.11',
  'bsnTrapVariable' => '1.3.6.1.4.1.14179.2.6.2',
  'bsnAuthFailureUserName' => '1.3.6.1.4.1.14179.2.6.2.1',
  'bsnAuthFailureUserType' => '1.3.6.1.4.1.14179.2.6.2.2',
  'bsnRemoteIPv4Address' => '1.3.6.1.4.1.14179.2.6.2.3',
  'bsnIpsecErrorCount' => '1.3.6.1.4.1.14179.2.6.2.4',
  'bsnIpsecSPI' => '1.3.6.1.4.1.14179.2.6.2.5',
  'bsnRemoteUdpPort' => '1.3.6.1.4.1.14179.2.6.2.6',
  'bsnIkeAuthMethod' => '1.3.6.1.4.1.14179.2.6.2.7',
  'bsnIkeTotalInitFailures' => '1.3.6.1.4.1.14179.2.6.2.8',
  'bsnIkeTotalInitNoResponses' => '1.3.6.1.4.1.14179.2.6.2.9',
  'bsnIkeTotalRespFailures' => '1.3.6.1.4.1.14179.2.6.2.10',
  'bsnNotifiesSent' => '1.3.6.1.4.1.14179.2.6.2.11',
  'bsnNotifiesReceived' => '1.3.6.1.4.1.14179.2.6.2.12',
  'bsnSuiteInitFailures' => '1.3.6.1.4.1.14179.2.6.2.13',
  'bsnSuiteRespondFailures' => '1.3.6.1.4.1.14179.2.6.2.14',
  'bsnInitiatorCookie' => '1.3.6.1.4.1.14179.2.6.2.15',
  'bsnResponderCookie' => '1.3.6.1.4.1.14179.2.6.2.16',
  'bsnIsakmpInvalidCookies' => '1.3.6.1.4.1.14179.2.6.2.17',
  'bsnCurrentRadiosCount' => '1.3.6.1.4.1.14179.2.6.2.18',
  'bsnLicenseRadioCount' => '1.3.6.1.4.1.14179.2.6.2.19',
  'bsnAPMacAddrTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.20',
  'bsnAPNameTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.21',
  'bsnAPSlotIdTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.22',
  'bsnAPChannelNumberTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.23',
  'bsnAPCoverageThresholdTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.24',
  'bsnAPCoverageFailedClients' => '1.3.6.1.4.1.14179.2.6.2.25',
  'bsnAPCoverageTotalClients' => '1.3.6.1.4.1.14179.2.6.2.26',
  'bsnClientMacAddr' => '1.3.6.1.4.1.14179.2.6.2.27',
  'bsnClientRssi' => '1.3.6.1.4.1.14179.2.6.2.28',
  'bsnClientSnr' => '1.3.6.1.4.1.14179.2.6.2.29',
  'bsnInterferenceEnergyBeforeChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.30',
  'bsnInterferenceEnergyAfterChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.31',
  'bsnAPPortNumberTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.32',
  'bsnMaxRogueCount' => '1.3.6.1.4.1.14179.2.6.2.33',
  'bsnStationMacAddress' => '1.3.6.1.4.1.14179.2.6.2.34',
  'bsnStationAPMacAddr' => '1.3.6.1.4.1.14179.2.6.2.35',
  'bsnStationAPIfSlotId' => '1.3.6.1.4.1.14179.2.6.2.36',
  'bsnStationReasonCode' => '1.3.6.1.4.1.14179.2.6.2.37',
  'bsnStationBlacklistingReasonCode' => '1.3.6.1.4.1.14179.2.6.2.38',
  'bsnStationUserName' => '1.3.6.1.4.1.14179.2.6.2.39',
  'bsnRogueAPOnWiredNetwork' => '1.3.6.1.4.1.14179.2.6.2.40',
  'bsnNavDosAttackSourceMacAddr' => '1.3.6.1.4.1.14179.2.6.2.41',
  'bsnWlanIdTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.42',
  'bsnUserIpAddress' => '1.3.6.1.4.1.14179.2.6.2.43',
  'bsnRogueAdhocMode' => '1.3.6.1.4.1.14179.2.6.2.44',
  'bsnClearTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.45',
  'bsnDuplicateIpTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.46',
  'bsnDuplicateIpTrapClear' => '1.3.6.1.4.1.14179.2.6.2.47',
  'bsnDuplicateIpReportedByAP' => '1.3.6.1.4.1.14179.2.6.2.48',
  'bsnTrustedApRadioPolicyRequired' => '1.3.6.1.4.1.14179.2.6.2.49',
  'bsnTrustedApEncryptionUsed' => '1.3.6.1.4.1.14179.2.6.2.50',
  'bsnTrustedApEncryptionRequired' => '1.3.6.1.4.1.14179.2.6.2.51',
  'bsnTrustedApRadioPolicyUsed' => '1.3.6.1.4.1.14179.2.6.2.52',
  'bsnNetworkType' => '1.3.6.1.4.1.14179.2.6.2.53',
  'bsnNetworkState' => '1.3.6.1.4.1.14179.2.6.2.54',
  'bsnSignatureType' => '1.3.6.1.4.1.14179.2.6.2.55',
  'bsnSignatureName' => '1.3.6.1.4.1.14179.2.6.2.56',
  'bsnSignatureDescription' => '1.3.6.1.4.1.14179.2.6.2.57',
  'bsnImpersonatedAPMacAddr' => '1.3.6.1.4.1.14179.2.6.2.58',
  'bsnTrustedApPreambleUsed' => '1.3.6.1.4.1.14179.2.6.2.59',
  'bsnTrustedApPreambleRequired' => '1.3.6.1.4.1.14179.2.6.2.60',
  'bsnSignatureAttackPreced' => '1.3.6.1.4.1.14179.2.6.2.61',
  'bsnSignatureAttackFrequency' => '1.3.6.1.4.1.14179.2.6.2.62',
  'bsnSignatureAttackChannel' => '1.3.6.1.4.1.14179.2.6.2.63',
  'bsnSignatureAttackerMacAddress' => '1.3.6.1.4.1.14179.2.6.2.64',
  'bsnLicenseKeyTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.65',
  'bsnApFunctionalityDisableReasonCode' => '1.3.6.1.4.1.14179.2.6.2.66',
  'bsnLicenseKeyFeatureSetTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.67',
  'bsnApRegulatoryDomain' => '1.3.6.1.4.1.14179.2.6.2.68',
  'bsnAPAuthorizationFailureCause' => '1.3.6.1.4.1.14179.2.6.2.69',
  'bsnAPIfUpDownCause' => '1.3.6.1.4.1.14179.2.6.2.70',
  'bsnAPInvalidRadioType' => '1.3.6.1.4.1.14179.2.6.2.71',
  'locationNotifyContent' => '1.3.6.1.4.1.14179.2.6.2.72',
  'bsnSignatureMacInfo' => '1.3.6.1.4.1.14179.2.6.2.73',
  'bsnImpersonatingSourceMacAddr' => '1.3.6.1.4.1.14179.2.6.2.74',
  'bsnAPPreviousChannelNumberTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.83',
  'bsnAPReasonCodeTrapVariable' => '1.3.6.1.4.1.14179.2.6.2.84',
  'bsnNoiseBeforeChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.85',
  'bsnNoiseAfterChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.86',
  'bsnInterferenceBeforeChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.87',
  'bsnInterferenceAfterChannelUpdate' => '1.3.6.1.4.1.14179.2.6.2.88',
  'bsnTraps' => '1.3.6.1.4.1.14179.2.6.3',
  'bsnDot11StationDisassociate' => '1.3.6.1.4.1.14179.2.6.3.1',
  'bsnDot11StationDeauthenticate' => '1.3.6.1.4.1.14179.2.6.3.2',
  'bsnDot11StationAuthenticateFail' => '1.3.6.1.4.1.14179.2.6.3.3',
  'bsnDot11StationAssociateFail' => '1.3.6.1.4.1.14179.2.6.3.4',
  'bsnAPUp' => '1.3.6.1.4.1.14179.2.6.3.5',
  'bsnAPDown' => '1.3.6.1.4.1.14179.2.6.3.6',
  'bsnAPAssociated' => '1.3.6.1.4.1.14179.2.6.3.7',
  'bsnAPDisassociated' => '1.3.6.1.4.1.14179.2.6.3.8',
  'bsnAPIfUp' => '1.3.6.1.4.1.14179.2.6.3.9',
  'bsnAPIfDown' => '1.3.6.1.4.1.14179.2.6.3.10',
  'bsnAPLoadProfileFailed' => '1.3.6.1.4.1.14179.2.6.3.11',
  'bsnAPNoiseProfileFailed' => '1.3.6.1.4.1.14179.2.6.3.12',
  'bsnAPInterferenceProfileFailed' => '1.3.6.1.4.1.14179.2.6.3.13',
  'bsnAPCoverageProfileFailed' => '1.3.6.1.4.1.14179.2.6.3.14',
  'bsnAPCurrentTxPowerChanged' => '1.3.6.1.4.1.14179.2.6.3.15',
  'bsnAPCurrentChannelChanged' => '1.3.6.1.4.1.14179.2.6.3.16',
  'bsnRrmDot11aGroupingDone' => '1.3.6.1.4.1.14179.2.6.3.21',
  'bsnRrmDot11bGroupingDone' => '1.3.6.1.4.1.14179.2.6.3.22',
  'bsnConfigSaved' => '1.3.6.1.4.1.14179.2.6.3.23',
  'bsnDot11EssCreated' => '1.3.6.1.4.1.14179.2.6.3.24',
  'bsnDot11EssDeleted' => '1.3.6.1.4.1.14179.2.6.3.25',
  'bsnRADIUSServerNotResponding' => '1.3.6.1.4.1.14179.2.6.3.26',
  'bsnAuthenticationFailure' => '1.3.6.1.4.1.14179.2.6.3.27',
  'bsnIpsecEspAuthFailureTrap' => '1.3.6.1.4.1.14179.2.6.3.28',
  'bsnIpsecEspReplayFailureTrap' => '1.3.6.1.4.1.14179.2.6.3.29',
  'bsnIpsecEspInvalidSpiTrap' => '1.3.6.1.4.1.14179.2.6.3.31',
  'bsnIpsecIkeNegFailure' => '1.3.6.1.4.1.14179.2.6.3.33',
  'bsnIpsecSuiteNegFailure' => '1.3.6.1.4.1.14179.2.6.3.34',
  'bsnIpsecInvalidCookieTrap' => '1.3.6.1.4.1.14179.2.6.3.35',
  'bsnRogueAPDetected' => '1.3.6.1.4.1.14179.2.6.3.36',
  'bsnAPLoadProfileUpdatedToPass' => '1.3.6.1.4.1.14179.2.6.3.37',
  'bsnAPNoiseProfileUpdatedToPass' => '1.3.6.1.4.1.14179.2.6.3.38',
  'bsnAPInterferenceProfileUpdatedToPass' => '1.3.6.1.4.1.14179.2.6.3.39',
  'bsnAPCoverageProfileUpdatedToPass' => '1.3.6.1.4.1.14179.2.6.3.40',
  'bsnRogueAPRemoved' => '1.3.6.1.4.1.14179.2.6.3.41',
  'bsnRadiosExceedLicenseCount' => '1.3.6.1.4.1.14179.2.6.3.42',
  'bsnSensedTemperatureTooHigh' => '1.3.6.1.4.1.14179.2.6.3.43',
  'bsnSensedTemperatureTooLow' => '1.3.6.1.4.1.14179.2.6.3.44',
  'bsnTemperatureSensorFailure' => '1.3.6.1.4.1.14179.2.6.3.45',
  'bsnTemperatureSensorClear' => '1.3.6.1.4.1.14179.2.6.3.46',
  'bsnPOEControllerFailure' => '1.3.6.1.4.1.14179.2.6.3.47',
  'bsnMaxRogueCountExceeded' => '1.3.6.1.4.1.14179.2.6.3.48',
  'bsnMaxRogueCountClear' => '1.3.6.1.4.1.14179.2.6.3.49',
  'bsnApMaxRogueCountExceeded' => '1.3.6.1.4.1.14179.2.6.3.50',
  'bsnApMaxRogueCountClear' => '1.3.6.1.4.1.14179.2.6.3.51',
  'bsnDot11StationBlacklisted' => '1.3.6.1.4.1.14179.2.6.3.52',
  'bsnDot11StationAssociate' => '1.3.6.1.4.1.14179.2.6.3.53',
  'bsnApBigNavDosAttack' => '1.3.6.1.4.1.14179.2.6.3.55',
  'bsnTooManyUnsuccessLoginAttempts' => '1.3.6.1.4.1.14179.2.6.3.56',
  'bsnWepKeyDecryptError' => '1.3.6.1.4.1.14179.2.6.3.57',
  'bsnWpaMicErrorCounterActivated' => '1.3.6.1.4.1.14179.2.6.3.58',
  'bsnRogueAPDetectedOnWiredNetwork' => '1.3.6.1.4.1.14179.2.6.3.59',
  'bsnApHasNoRadioCards' => '1.3.6.1.4.1.14179.2.6.3.60',
  'bsnDuplicateIpAddressReported' => '1.3.6.1.4.1.14179.2.6.3.61',
  'bsnAPContainedAsARogue' => '1.3.6.1.4.1.14179.2.6.3.62',
  'bsnTrustedApHasInvalidSsid' => '1.3.6.1.4.1.14179.2.6.3.63',
  'bsnTrustedApIsMissing' => '1.3.6.1.4.1.14179.2.6.3.64',
  'bsnAdhocRogueAutoContained' => '1.3.6.1.4.1.14179.2.6.3.65',
  'bsnRogueApAutoContained' => '1.3.6.1.4.1.14179.2.6.3.66',
  'bsnTrustedApHasInvalidEncryption' => '1.3.6.1.4.1.14179.2.6.3.67',
  'bsnTrustedApHasInvalidRadioPolicy' => '1.3.6.1.4.1.14179.2.6.3.68',
  'bsnNetworkStateChanged' => '1.3.6.1.4.1.14179.2.6.3.69',
  'bsnSignatureAttackDetected' => '1.3.6.1.4.1.14179.2.6.3.70',
  'bsnAPRadioCardTxFailure' => '1.3.6.1.4.1.14179.2.6.3.71',
  'bsnAPRadioCardTxFailureClear' => '1.3.6.1.4.1.14179.2.6.3.72',
  'bsnAPRadioCardRxFailure' => '1.3.6.1.4.1.14179.2.6.3.73',
  'bsnAPRadioCardRxFailureClear' => '1.3.6.1.4.1.14179.2.6.3.74',
  'bsnAPImpersonationDetected' => '1.3.6.1.4.1.14179.2.6.3.75',
  'bsnTrustedApHasInvalidPreamble' => '1.3.6.1.4.1.14179.2.6.3.76',
  'bsnAPIPAddressFallback' => '1.3.6.1.4.1.14179.2.6.3.77',
  'bsnAPFunctionalityDisabled' => '1.3.6.1.4.1.14179.2.6.3.78',
  'bsnAPRegulatoryDomainMismatch' => '1.3.6.1.4.1.14179.2.6.3.79',
  'bsnRxMulticastQueueFull' => '1.3.6.1.4.1.14179.2.6.3.80',
  'bsnRadarChannelDetected' => '1.3.6.1.4.1.14179.2.6.3.81',
  'bsnRadarChannelCleared' => '1.3.6.1.4.1.14179.2.6.3.82',
  'bsnAPAuthorizationFailure' => '1.3.6.1.4.1.14179.2.6.3.83',
  'radioCoreDumpTrap' => '1.3.6.1.4.1.14179.2.6.3.84',
  'invalidRadioTrap' => '1.3.6.1.4.1.14179.2.6.3.85',
  'countryChangeTrap' => '1.3.6.1.4.1.14179.2.6.3.86',
  'unsupportedAPTrap' => '1.3.6.1.4.1.14179.2.6.3.87',
  'heartbeatLossTrap' => '1.3.6.1.4.1.14179.2.6.3.88',
  'locationNotifyTrap' => '1.3.6.1.4.1.14179.2.6.3.89',
  'bsnUtility' => '1.3.6.1.4.1.14179.2.7',
  'bsnSyslog' => '1.3.6.1.4.1.14179.2.7.1',
  'bsnSyslogEnable' => '1.3.6.1.4.1.14179.2.7.1.1',
  'bsnSyslogRemoteAddress' => '1.3.6.1.4.1.14179.2.7.1.2',
  'bsnPing' => '1.3.6.1.4.1.14179.2.7.2',
  'bsnPingTestTable' => '1.3.6.1.4.1.14179.2.7.2.1',
  'bsnPingTestEntry' => '1.3.6.1.4.1.14179.2.7.2.1.1',
  'bsnPingTestId' => '1.3.6.1.4.1.14179.2.7.2.1.1.1',
  'bsnPingTestIPAddress' => '1.3.6.1.4.1.14179.2.7.2.1.1.2',
  'bsnPingTestSendCount' => '1.3.6.1.4.1.14179.2.7.2.1.1.3',
  'bsnPingTestReceivedCount' => '1.3.6.1.4.1.14179.2.7.2.1.1.4',
  'bsnPingTestStatus' => '1.3.6.1.4.1.14179.2.7.2.1.1.5',
  'bsnPingTestMaxTimeInterval' => '1.3.6.1.4.1.14179.2.7.2.1.1.6',
  'bsnPingTestMinTimeInterval' => '1.3.6.1.4.1.14179.2.7.2.1.1.7',
  'bsnPingTestAvgTimeInterval' => '1.3.6.1.4.1.14179.2.7.2.1.1.8',
  'bsnPingTestRowStatus' => '1.3.6.1.4.1.14179.2.7.2.1.1.25',
  'bsnLinkTest' => '1.3.6.1.4.1.14179.2.7.3',
  'bsnLinkTestTable' => '1.3.6.1.4.1.14179.2.7.3.1',
  'bsnLinkTestEntry' => '1.3.6.1.4.1.14179.2.7.3.1.1',
  'bsnLinkTestId' => '1.3.6.1.4.1.14179.2.7.3.1.1.1',
  'bsnLinkTestMacAddress' => '1.3.6.1.4.1.14179.2.7.3.1.1.2',
  'bsnLinkTestSendPktCount' => '1.3.6.1.4.1.14179.2.7.3.1.1.3',
  'bsnLinkTestSendPktLength' => '1.3.6.1.4.1.14179.2.7.3.1.1.4',
  'bsnLinkTestReceivedPktCount' => '1.3.6.1.4.1.14179.2.7.3.1.1.5',
  'bsnLinkTestClientRSSI' => '1.3.6.1.4.1.14179.2.7.3.1.1.6',
  'bsnLinkTestLocalSNR' => '1.3.6.1.4.1.14179.2.7.3.1.1.7',
  'bsnLinkTestLocalRSSI' => '1.3.6.1.4.1.14179.2.7.3.1.1.8',
  'bsnLinkTestStatus' => '1.3.6.1.4.1.14179.2.7.3.1.1.9',
  'bsnLinkTestRowStatus' => '1.3.6.1.4.1.14179.2.7.3.1.1.30',
  'bsnMobility' => '1.3.6.1.4.1.14179.2.8',
  'bsnMobilityConfig' => '1.3.6.1.4.1.14179.2.8.1',
  'bsnMobilityProtocolPortNum' => '1.3.6.1.4.1.14179.2.8.1.1',
  'bsnMobilityDynamicDiscovery' => '1.3.6.1.4.1.14179.2.8.1.3',
  'bsnMobilityStatsReset' => '1.3.6.1.4.1.14179.2.8.1.4',
  'bsnMobilityGroupMembersTable' => '1.3.6.1.4.1.14179.2.8.1.10',
  'bsnMobilityGroupMembersEntry' => '1.3.6.1.4.1.14179.2.8.1.10.1',
  'bsnMobilityGroupMemberMacAddress' => '1.3.6.1.4.1.14179.2.8.1.10.1.1',
  'bsnMobilityGroupMemberIPAddress' => '1.3.6.1.4.1.14179.2.8.1.10.1.2',
  'bsnMobilityGroupMemberGroupName' => '1.3.6.1.4.1.14179.2.8.1.10.1.3',
  'bsnMobilityGroupMemberRowStatus' => '1.3.6.1.4.1.14179.2.8.1.10.1.22',
  'bsnMobilityAnchorsTable' => '1.3.6.1.4.1.14179.2.8.1.11',
  'bsnMobilityAnchorsEntry' => '1.3.6.1.4.1.14179.2.8.1.11.1',
  'bsnMobilityAnchorWlanSsid' => '1.3.6.1.4.1.14179.2.8.1.11.1.1',
  'bsnMobilityAnchorSwitchIPAddress' => '1.3.6.1.4.1.14179.2.8.1.11.1.2',
  'bsnMobilityAnchorRowStatus' => '1.3.6.1.4.1.14179.2.8.1.11.1.20',
  'bsnMobilityStats' => '1.3.6.1.4.1.14179.2.8.2',
  'bsnTotalHandoffRequests' => '1.3.6.1.4.1.14179.2.8.2.1',
  'bsnTotalHandoffs' => '1.3.6.1.4.1.14179.2.8.2.2',
  'bsnCurrentExportedClients' => '1.3.6.1.4.1.14179.2.8.2.3',
  'bsnTotalExportedClients' => '1.3.6.1.4.1.14179.2.8.2.4',
  'bsnCurrentImportedClients' => '1.3.6.1.4.1.14179.2.8.2.5',
  'bsnTotalImportedClients' => '1.3.6.1.4.1.14179.2.8.2.6',
  'bsnTotalHandoffErrors' => '1.3.6.1.4.1.14179.2.8.2.7',
  'bsnTotalCommunicationErrors' => '1.3.6.1.4.1.14179.2.8.2.8',
  'bsnMobilityGroupDirectoryTable' => '1.3.6.1.4.1.14179.2.8.2.9',
  'bsnMobilityGroupDirectoryEntry' => '1.3.6.1.4.1.14179.2.8.2.9.1',
  'bsnGroupDirectoryMemberIPAddress' => '1.3.6.1.4.1.14179.2.8.2.9.1.1',
  'bsnGroupDirectoryMemberMacAddress' => '1.3.6.1.4.1.14179.2.8.2.9.1.2',
  'bsnGroupDirectoryDicoveryType' => '1.3.6.1.4.1.14179.2.8.2.9.1.3',
  'bsnMemberCurrentAnchoredClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.4',
  'bsnMemberTotalAnchoredClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.5',
  'bsnMemberCurrentExportedClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.6',
  'bsnMemberTotalExportedClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.7',
  'bsnMemberCurrentImportedClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.8',
  'bsnMemberTotalImportedClients' => '1.3.6.1.4.1.14179.2.8.2.9.1.9',
  'bsnMemberTotalHandoffErrors' => '1.3.6.1.4.1.14179.2.8.2.9.1.10',
  'bsnMemberTotalCommunicationErrors' => '1.3.6.1.4.1.14179.2.8.2.9.1.30',
  'bsnTotalReceiveErrors' => '1.3.6.1.4.1.14179.2.8.2.10',
  'bsnTotalTransmitErrors' => '1.3.6.1.4.1.14179.2.8.2.11',
  'bsnTotalResponsesRetransmitted' => '1.3.6.1.4.1.14179.2.8.2.12',
  'bsnTotalHandoffEndRequestsReceived' => '1.3.6.1.4.1.14179.2.8.2.13',
  'bsnTotalStateTransitionsDisallowed' => '1.3.6.1.4.1.14179.2.8.2.14',
  'bsnTotalResourceErrors' => '1.3.6.1.4.1.14179.2.8.2.15',
  'bsnTotalHandoffRequestsSent' => '1.3.6.1.4.1.14179.2.8.2.16',
  'bsnTotalHandoffRepliesReceived' => '1.3.6.1.4.1.14179.2.8.2.17',
  'bsnTotalHandoffAsLocalReceived' => '1.3.6.1.4.1.14179.2.8.2.18',
  'bsnTotalHandoffAsForeignReceived' => '1.3.6.1.4.1.14179.2.8.2.19',
  'bsnTotalHandoffDeniesReceived' => '1.3.6.1.4.1.14179.2.8.2.20',
  'bsnTotalAnchorRequestsSent' => '1.3.6.1.4.1.14179.2.8.2.21',
  'bsnTotalAnchorDenyReceived' => '1.3.6.1.4.1.14179.2.8.2.22',
  'bsnTotalAnchorGrantReceived' => '1.3.6.1.4.1.14179.2.8.2.23',
  'bsnTotalAnchorTransferReceived' => '1.3.6.1.4.1.14179.2.8.2.24',
  'bsnTotalHandoffRequestsIgnored' => '1.3.6.1.4.1.14179.2.8.2.25',
  'bsnTotalPingPongHandoffRequestsDropped' => '1.3.6.1.4.1.14179.2.8.2.26',
  'bsnTotalHandoffRequestsDropped' => '1.3.6.1.4.1.14179.2.8.2.27',
  'bsnTotalHandoffRequestsDenied' => '1.3.6.1.4.1.14179.2.8.2.28',
  'bsnTotalClientHandoffAsLocal' => '1.3.6.1.4.1.14179.2.8.2.29',
  'bsnTotalClientHandoffAsForeign' => '1.3.6.1.4.1.14179.2.8.2.30',
  'bsnTotalAnchorRequestsReceived' => '1.3.6.1.4.1.14179.2.8.2.31',
  'bsnTotalAnchorRequestsDenied' => '1.3.6.1.4.1.14179.2.8.2.32',
  'bsnTotalAnchorRequestsGranted' => '1.3.6.1.4.1.14179.2.8.2.33',
  'bsnTotalAnchorTransferred' => '1.3.6.1.4.1.14179.2.8.2.34',
  'bsnTotalHandoffRequestsReceived' => '1.3.6.1.4.1.14179.2.8.2.35',
  'bsnIpsec' => '1.3.6.1.4.1.14179.2.9',
  'bsnWrasIpsecCACertificate' => '1.3.6.1.4.1.14179.2.9.1',
  'bsnWrasIpsecCACertificateUpdate' => '1.3.6.1.4.1.14179.2.9.2',
  'bsnWrasIpsecCertTable' => '1.3.6.1.4.1.14179.2.9.3',
  'bsnWrasIpsecCertEntry' => '1.3.6.1.4.1.14179.2.9.3.1',
  'bsnWrasIpsecCertName' => '1.3.6.1.4.1.14179.2.9.3.1.1',
  'bsnWrasIpsecCertificateUpdate' => '1.3.6.1.4.1.14179.2.9.3.1.2',
  'bsnWrasIpsecCertificate' => '1.3.6.1.4.1.14179.2.9.3.1.3',
  'bsnWrasIpsecCertPassword' => '1.3.6.1.4.1.14179.2.9.3.1.4',
  'bsnWrasIpsecCertStatus' => '1.3.6.1.4.1.14179.2.9.3.1.24',
  'bsnAPGroupsVlanConfig' => '1.3.6.1.4.1.14179.2.10',
  'bsnAPGroupsVlanFeature' => '1.3.6.1.4.1.14179.2.10.1',
  'bsnAPGroupsVlanTable' => '1.3.6.1.4.1.14179.2.10.2',
  'bsnAPGroupsVlanEntry' => '1.3.6.1.4.1.14179.2.10.2.1',
  'bsnAPGroupsVlanName' => '1.3.6.1.4.1.14179.2.10.2.1.1',
  'bsnAPGroupsVlanDescription' => '1.3.6.1.4.1.14179.2.10.2.1.2',
  'bsnAPGroupsVlanRowStatus' => '1.3.6.1.4.1.14179.2.10.2.1.20',
  'bsnAPGroupsVlanMappingTable' => '1.3.6.1.4.1.14179.2.10.3',
  'bsnAPGroupsVlanMappingEntry' => '1.3.6.1.4.1.14179.2.10.3.1',
  'bsnAPGroupsVlanMappingSsid' => '1.3.6.1.4.1.14179.2.10.3.1.1',
  'bsnAPGroupsVlanMappingInterfaceName' => '1.3.6.1.4.1.14179.2.10.3.1.2',
  'bsnAPGroupsVlanMappingRowStatus' => '1.3.6.1.4.1.14179.2.10.3.1.20',
  'bsnWrasGroups' => '1.3.6.1.4.1.14179.2.50',
  'bsnEssGroup' => '1.3.6.1.4.1.14179.2.50.1',
  'bsnApGroup' => '1.3.6.1.4.1.14179.2.50.2',
  'bsnGlobalDot11Group' => '1.3.6.1.4.1.14179.2.50.3',
  'bsnRrmGroup' => '1.3.6.1.4.1.14179.2.50.4',
  'bsnAAAGroup' => '1.3.6.1.4.1.14179.2.50.5',
  'bsnTrapsGroup' => '1.3.6.1.4.1.14179.2.50.6',
  'bsnUtilityGroup' => '1.3.6.1.4.1.14179.2.50.7',
  'bsnMobilityGroup' => '1.3.6.1.4.1.14179.2.50.8',
  'bsnIpsecGroup' => '1.3.6.1.4.1.14179.2.50.9',
  'bsnWrasDepGroup' => '1.3.6.1.4.1.14179.2.50.10',
  'bsnWrasObsGroup' => '1.3.6.1.4.1.14179.2.50.11',
  'bsnWrasTrap' => '1.3.6.1.4.1.14179.2.50.12',
  'bsnEssGroupRev1' => '1.3.6.1.4.1.14179.2.50.13',
  'bsnGlobalDot11GroupRev1' => '1.3.6.1.4.1.14179.2.50.14',
  'bsnAAAGroupRev1' => '1.3.6.1.4.1.14179.2.50.15',
  'bsnTrapsGroupRev1' => '1.3.6.1.4.1.14179.2.50.16',
  'bsnWrasTrapRev1' => '1.3.6.1.4.1.14179.2.50.17',
  'bsnApGroupRev1' => '1.3.6.1.4.1.14179.2.50.18',
  'bsnUtilityGroupRev1' => '1.3.6.1.4.1.14179.2.50.19',
  'bsnWrasObsGroupRev1' => '1.3.6.1.4.1.14179.2.50.20',
  'bsnWrasObsTrap' => '1.3.6.1.4.1.14179.2.50.21',
  'bsnWrasCompliances' => '1.3.6.1.4.1.14179.2.51',
  'bsnWrasCompliance' => '1.3.6.1.4.1.14179.2.51.1',
  'bsnWrasComplianceRev1' => '1.3.6.1.4.1.14179.2.51.2',
};


1;

__END__
